# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .get_ami import *
from .get_ami_ids import *
from .get_arn import *
from .get_autoscaling_groups import *
from .get_availability_zone import *
from .get_availability_zones import *
from .get_billing_service_account import *
from .get_caller_identity import *
from .get_canonical_user_id import *
from .get_default_tags import *
from .get_elastic_ip import *
from .get_ip_ranges import *
from .get_partition import *
from .get_prefix_list import *
from .get_region import *
from .get_regions import *
from .get_service import *
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_aws.accessanalyzer as __accessanalyzer
    accessanalyzer = __accessanalyzer
    import pulumi_aws.account as __account
    account = __account
    import pulumi_aws.acm as __acm
    acm = __acm
    import pulumi_aws.acmpca as __acmpca
    acmpca = __acmpca
    import pulumi_aws.alb as __alb
    alb = __alb
    import pulumi_aws.amp as __amp
    amp = __amp
    import pulumi_aws.amplify as __amplify
    amplify = __amplify
    import pulumi_aws.apigateway as __apigateway
    apigateway = __apigateway
    import pulumi_aws.apigatewayv2 as __apigatewayv2
    apigatewayv2 = __apigatewayv2
    import pulumi_aws.appautoscaling as __appautoscaling
    appautoscaling = __appautoscaling
    import pulumi_aws.appconfig as __appconfig
    appconfig = __appconfig
    import pulumi_aws.applicationloadbalancing as __applicationloadbalancing
    applicationloadbalancing = __applicationloadbalancing
    import pulumi_aws.appmesh as __appmesh
    appmesh = __appmesh
    import pulumi_aws.apprunner as __apprunner
    apprunner = __apprunner
    import pulumi_aws.appstream as __appstream
    appstream = __appstream
    import pulumi_aws.appsync as __appsync
    appsync = __appsync
    import pulumi_aws.athena as __athena
    athena = __athena
    import pulumi_aws.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumi_aws.autoscalingplans as __autoscalingplans
    autoscalingplans = __autoscalingplans
    import pulumi_aws.backup as __backup
    backup = __backup
    import pulumi_aws.batch as __batch
    batch = __batch
    import pulumi_aws.budgets as __budgets
    budgets = __budgets
    import pulumi_aws.cfg as __cfg
    cfg = __cfg
    import pulumi_aws.chime as __chime
    chime = __chime
    import pulumi_aws.cloud9 as __cloud9
    cloud9 = __cloud9
    import pulumi_aws.cloudcontrol as __cloudcontrol
    cloudcontrol = __cloudcontrol
    import pulumi_aws.cloudformation as __cloudformation
    cloudformation = __cloudformation
    import pulumi_aws.cloudfront as __cloudfront
    cloudfront = __cloudfront
    import pulumi_aws.cloudhsmv2 as __cloudhsmv2
    cloudhsmv2 = __cloudhsmv2
    import pulumi_aws.cloudsearch as __cloudsearch
    cloudsearch = __cloudsearch
    import pulumi_aws.cloudtrail as __cloudtrail
    cloudtrail = __cloudtrail
    import pulumi_aws.cloudwatch as __cloudwatch
    cloudwatch = __cloudwatch
    import pulumi_aws.codeartifact as __codeartifact
    codeartifact = __codeartifact
    import pulumi_aws.codebuild as __codebuild
    codebuild = __codebuild
    import pulumi_aws.codecommit as __codecommit
    codecommit = __codecommit
    import pulumi_aws.codedeploy as __codedeploy
    codedeploy = __codedeploy
    import pulumi_aws.codepipeline as __codepipeline
    codepipeline = __codepipeline
    import pulumi_aws.codestarconnections as __codestarconnections
    codestarconnections = __codestarconnections
    import pulumi_aws.codestarnotifications as __codestarnotifications
    codestarnotifications = __codestarnotifications
    import pulumi_aws.cognito as __cognito
    cognito = __cognito
    import pulumi_aws.config as __config
    config = __config
    import pulumi_aws.connect as __connect
    connect = __connect
    import pulumi_aws.cur as __cur
    cur = __cur
    import pulumi_aws.dataexchange as __dataexchange
    dataexchange = __dataexchange
    import pulumi_aws.datapipeline as __datapipeline
    datapipeline = __datapipeline
    import pulumi_aws.datasync as __datasync
    datasync = __datasync
    import pulumi_aws.dax as __dax
    dax = __dax
    import pulumi_aws.detective as __detective
    detective = __detective
    import pulumi_aws.devicefarm as __devicefarm
    devicefarm = __devicefarm
    import pulumi_aws.directconnect as __directconnect
    directconnect = __directconnect
    import pulumi_aws.directoryservice as __directoryservice
    directoryservice = __directoryservice
    import pulumi_aws.dlm as __dlm
    dlm = __dlm
    import pulumi_aws.dms as __dms
    dms = __dms
    import pulumi_aws.docdb as __docdb
    docdb = __docdb
    import pulumi_aws.dynamodb as __dynamodb
    dynamodb = __dynamodb
    import pulumi_aws.ebs as __ebs
    ebs = __ebs
    import pulumi_aws.ec2 as __ec2
    ec2 = __ec2
    import pulumi_aws.ec2clientvpn as __ec2clientvpn
    ec2clientvpn = __ec2clientvpn
    import pulumi_aws.ec2transitgateway as __ec2transitgateway
    ec2transitgateway = __ec2transitgateway
    import pulumi_aws.ecr as __ecr
    ecr = __ecr
    import pulumi_aws.ecrpublic as __ecrpublic
    ecrpublic = __ecrpublic
    import pulumi_aws.ecs as __ecs
    ecs = __ecs
    import pulumi_aws.efs as __efs
    efs = __efs
    import pulumi_aws.eks as __eks
    eks = __eks
    import pulumi_aws.elasticache as __elasticache
    elasticache = __elasticache
    import pulumi_aws.elasticbeanstalk as __elasticbeanstalk
    elasticbeanstalk = __elasticbeanstalk
    import pulumi_aws.elasticloadbalancing as __elasticloadbalancing
    elasticloadbalancing = __elasticloadbalancing
    import pulumi_aws.elasticloadbalancingv2 as __elasticloadbalancingv2
    elasticloadbalancingv2 = __elasticloadbalancingv2
    import pulumi_aws.elasticsearch as __elasticsearch
    elasticsearch = __elasticsearch
    import pulumi_aws.elastictranscoder as __elastictranscoder
    elastictranscoder = __elastictranscoder
    import pulumi_aws.elb as __elb
    elb = __elb
    import pulumi_aws.emr as __emr
    emr = __emr
    import pulumi_aws.fms as __fms
    fms = __fms
    import pulumi_aws.fsx as __fsx
    fsx = __fsx
    import pulumi_aws.gamelift as __gamelift
    gamelift = __gamelift
    import pulumi_aws.glacier as __glacier
    glacier = __glacier
    import pulumi_aws.globalaccelerator as __globalaccelerator
    globalaccelerator = __globalaccelerator
    import pulumi_aws.glue as __glue
    glue = __glue
    import pulumi_aws.grafana as __grafana
    grafana = __grafana
    import pulumi_aws.guardduty as __guardduty
    guardduty = __guardduty
    import pulumi_aws.iam as __iam
    iam = __iam
    import pulumi_aws.identitystore as __identitystore
    identitystore = __identitystore
    import pulumi_aws.imagebuilder as __imagebuilder
    imagebuilder = __imagebuilder
    import pulumi_aws.inspector as __inspector
    inspector = __inspector
    import pulumi_aws.iot as __iot
    iot = __iot
    import pulumi_aws.kinesis as __kinesis
    kinesis = __kinesis
    import pulumi_aws.kinesisanalyticsv2 as __kinesisanalyticsv2
    kinesisanalyticsv2 = __kinesisanalyticsv2
    import pulumi_aws.kms as __kms
    kms = __kms
    import pulumi_aws.lakeformation as __lakeformation
    lakeformation = __lakeformation
    import pulumi_aws.lambda_ as __lambda_
    lambda_ = __lambda_
    import pulumi_aws.lb as __lb
    lb = __lb
    import pulumi_aws.lex as __lex
    lex = __lex
    import pulumi_aws.licensemanager as __licensemanager
    licensemanager = __licensemanager
    import pulumi_aws.lightsail as __lightsail
    lightsail = __lightsail
    import pulumi_aws.macie as __macie
    macie = __macie
    import pulumi_aws.macie2 as __macie2
    macie2 = __macie2
    import pulumi_aws.mediaconvert as __mediaconvert
    mediaconvert = __mediaconvert
    import pulumi_aws.mediapackage as __mediapackage
    mediapackage = __mediapackage
    import pulumi_aws.mediastore as __mediastore
    mediastore = __mediastore
    import pulumi_aws.memorydb as __memorydb
    memorydb = __memorydb
    import pulumi_aws.mq as __mq
    mq = __mq
    import pulumi_aws.msk as __msk
    msk = __msk
    import pulumi_aws.mskconnect as __mskconnect
    mskconnect = __mskconnect
    import pulumi_aws.mwaa as __mwaa
    mwaa = __mwaa
    import pulumi_aws.neptune as __neptune
    neptune = __neptune
    import pulumi_aws.networkfirewall as __networkfirewall
    networkfirewall = __networkfirewall
    import pulumi_aws.networkmanager as __networkmanager
    networkmanager = __networkmanager
    import pulumi_aws.opsworks as __opsworks
    opsworks = __opsworks
    import pulumi_aws.organizations as __organizations
    organizations = __organizations
    import pulumi_aws.outposts as __outposts
    outposts = __outposts
    import pulumi_aws.pinpoint as __pinpoint
    pinpoint = __pinpoint
    import pulumi_aws.pricing as __pricing
    pricing = __pricing
    import pulumi_aws.qldb as __qldb
    qldb = __qldb
    import pulumi_aws.quicksight as __quicksight
    quicksight = __quicksight
    import pulumi_aws.ram as __ram
    ram = __ram
    import pulumi_aws.rds as __rds
    rds = __rds
    import pulumi_aws.redshift as __redshift
    redshift = __redshift
    import pulumi_aws.resourcegroups as __resourcegroups
    resourcegroups = __resourcegroups
    import pulumi_aws.resourcegroupstaggingapi as __resourcegroupstaggingapi
    resourcegroupstaggingapi = __resourcegroupstaggingapi
    import pulumi_aws.route53 as __route53
    route53 = __route53
    import pulumi_aws.route53domains as __route53domains
    route53domains = __route53domains
    import pulumi_aws.route53recoverycontrol as __route53recoverycontrol
    route53recoverycontrol = __route53recoverycontrol
    import pulumi_aws.route53recoveryreadiness as __route53recoveryreadiness
    route53recoveryreadiness = __route53recoveryreadiness
    import pulumi_aws.s3 as __s3
    s3 = __s3
    import pulumi_aws.s3control as __s3control
    s3control = __s3control
    import pulumi_aws.s3outposts as __s3outposts
    s3outposts = __s3outposts
    import pulumi_aws.sagemaker as __sagemaker
    sagemaker = __sagemaker
    import pulumi_aws.schemas as __schemas
    schemas = __schemas
    import pulumi_aws.secretsmanager as __secretsmanager
    secretsmanager = __secretsmanager
    import pulumi_aws.securityhub as __securityhub
    securityhub = __securityhub
    import pulumi_aws.serverlessrepository as __serverlessrepository
    serverlessrepository = __serverlessrepository
    import pulumi_aws.servicecatalog as __servicecatalog
    servicecatalog = __servicecatalog
    import pulumi_aws.servicediscovery as __servicediscovery
    servicediscovery = __servicediscovery
    import pulumi_aws.servicequotas as __servicequotas
    servicequotas = __servicequotas
    import pulumi_aws.ses as __ses
    ses = __ses
    import pulumi_aws.sfn as __sfn
    sfn = __sfn
    import pulumi_aws.shield as __shield
    shield = __shield
    import pulumi_aws.signer as __signer
    signer = __signer
    import pulumi_aws.simpledb as __simpledb
    simpledb = __simpledb
    import pulumi_aws.sns as __sns
    sns = __sns
    import pulumi_aws.sqs as __sqs
    sqs = __sqs
    import pulumi_aws.ssm as __ssm
    ssm = __ssm
    import pulumi_aws.ssoadmin as __ssoadmin
    ssoadmin = __ssoadmin
    import pulumi_aws.storagegateway as __storagegateway
    storagegateway = __storagegateway
    import pulumi_aws.swf as __swf
    swf = __swf
    import pulumi_aws.synthetics as __synthetics
    synthetics = __synthetics
    import pulumi_aws.timestreamwrite as __timestreamwrite
    timestreamwrite = __timestreamwrite
    import pulumi_aws.transfer as __transfer
    transfer = __transfer
    import pulumi_aws.waf as __waf
    waf = __waf
    import pulumi_aws.wafregional as __wafregional
    wafregional = __wafregional
    import pulumi_aws.wafv2 as __wafv2
    wafv2 = __wafv2
    import pulumi_aws.worklink as __worklink
    worklink = __worklink
    import pulumi_aws.workspaces as __workspaces
    workspaces = __workspaces
    import pulumi_aws.xray as __xray
    xray = __xray
else:
    accessanalyzer = _utilities.lazy_import('pulumi_aws.accessanalyzer')
    account = _utilities.lazy_import('pulumi_aws.account')
    acm = _utilities.lazy_import('pulumi_aws.acm')
    acmpca = _utilities.lazy_import('pulumi_aws.acmpca')
    alb = _utilities.lazy_import('pulumi_aws.alb')
    amp = _utilities.lazy_import('pulumi_aws.amp')
    amplify = _utilities.lazy_import('pulumi_aws.amplify')
    apigateway = _utilities.lazy_import('pulumi_aws.apigateway')
    apigatewayv2 = _utilities.lazy_import('pulumi_aws.apigatewayv2')
    appautoscaling = _utilities.lazy_import('pulumi_aws.appautoscaling')
    appconfig = _utilities.lazy_import('pulumi_aws.appconfig')
    applicationloadbalancing = _utilities.lazy_import('pulumi_aws.applicationloadbalancing')
    appmesh = _utilities.lazy_import('pulumi_aws.appmesh')
    apprunner = _utilities.lazy_import('pulumi_aws.apprunner')
    appstream = _utilities.lazy_import('pulumi_aws.appstream')
    appsync = _utilities.lazy_import('pulumi_aws.appsync')
    athena = _utilities.lazy_import('pulumi_aws.athena')
    autoscaling = _utilities.lazy_import('pulumi_aws.autoscaling')
    autoscalingplans = _utilities.lazy_import('pulumi_aws.autoscalingplans')
    backup = _utilities.lazy_import('pulumi_aws.backup')
    batch = _utilities.lazy_import('pulumi_aws.batch')
    budgets = _utilities.lazy_import('pulumi_aws.budgets')
    cfg = _utilities.lazy_import('pulumi_aws.cfg')
    chime = _utilities.lazy_import('pulumi_aws.chime')
    cloud9 = _utilities.lazy_import('pulumi_aws.cloud9')
    cloudcontrol = _utilities.lazy_import('pulumi_aws.cloudcontrol')
    cloudformation = _utilities.lazy_import('pulumi_aws.cloudformation')
    cloudfront = _utilities.lazy_import('pulumi_aws.cloudfront')
    cloudhsmv2 = _utilities.lazy_import('pulumi_aws.cloudhsmv2')
    cloudsearch = _utilities.lazy_import('pulumi_aws.cloudsearch')
    cloudtrail = _utilities.lazy_import('pulumi_aws.cloudtrail')
    cloudwatch = _utilities.lazy_import('pulumi_aws.cloudwatch')
    codeartifact = _utilities.lazy_import('pulumi_aws.codeartifact')
    codebuild = _utilities.lazy_import('pulumi_aws.codebuild')
    codecommit = _utilities.lazy_import('pulumi_aws.codecommit')
    codedeploy = _utilities.lazy_import('pulumi_aws.codedeploy')
    codepipeline = _utilities.lazy_import('pulumi_aws.codepipeline')
    codestarconnections = _utilities.lazy_import('pulumi_aws.codestarconnections')
    codestarnotifications = _utilities.lazy_import('pulumi_aws.codestarnotifications')
    cognito = _utilities.lazy_import('pulumi_aws.cognito')
    config = _utilities.lazy_import('pulumi_aws.config')
    connect = _utilities.lazy_import('pulumi_aws.connect')
    cur = _utilities.lazy_import('pulumi_aws.cur')
    dataexchange = _utilities.lazy_import('pulumi_aws.dataexchange')
    datapipeline = _utilities.lazy_import('pulumi_aws.datapipeline')
    datasync = _utilities.lazy_import('pulumi_aws.datasync')
    dax = _utilities.lazy_import('pulumi_aws.dax')
    detective = _utilities.lazy_import('pulumi_aws.detective')
    devicefarm = _utilities.lazy_import('pulumi_aws.devicefarm')
    directconnect = _utilities.lazy_import('pulumi_aws.directconnect')
    directoryservice = _utilities.lazy_import('pulumi_aws.directoryservice')
    dlm = _utilities.lazy_import('pulumi_aws.dlm')
    dms = _utilities.lazy_import('pulumi_aws.dms')
    docdb = _utilities.lazy_import('pulumi_aws.docdb')
    dynamodb = _utilities.lazy_import('pulumi_aws.dynamodb')
    ebs = _utilities.lazy_import('pulumi_aws.ebs')
    ec2 = _utilities.lazy_import('pulumi_aws.ec2')
    ec2clientvpn = _utilities.lazy_import('pulumi_aws.ec2clientvpn')
    ec2transitgateway = _utilities.lazy_import('pulumi_aws.ec2transitgateway')
    ecr = _utilities.lazy_import('pulumi_aws.ecr')
    ecrpublic = _utilities.lazy_import('pulumi_aws.ecrpublic')
    ecs = _utilities.lazy_import('pulumi_aws.ecs')
    efs = _utilities.lazy_import('pulumi_aws.efs')
    eks = _utilities.lazy_import('pulumi_aws.eks')
    elasticache = _utilities.lazy_import('pulumi_aws.elasticache')
    elasticbeanstalk = _utilities.lazy_import('pulumi_aws.elasticbeanstalk')
    elasticloadbalancing = _utilities.lazy_import('pulumi_aws.elasticloadbalancing')
    elasticloadbalancingv2 = _utilities.lazy_import('pulumi_aws.elasticloadbalancingv2')
    elasticsearch = _utilities.lazy_import('pulumi_aws.elasticsearch')
    elastictranscoder = _utilities.lazy_import('pulumi_aws.elastictranscoder')
    elb = _utilities.lazy_import('pulumi_aws.elb')
    emr = _utilities.lazy_import('pulumi_aws.emr')
    fms = _utilities.lazy_import('pulumi_aws.fms')
    fsx = _utilities.lazy_import('pulumi_aws.fsx')
    gamelift = _utilities.lazy_import('pulumi_aws.gamelift')
    glacier = _utilities.lazy_import('pulumi_aws.glacier')
    globalaccelerator = _utilities.lazy_import('pulumi_aws.globalaccelerator')
    glue = _utilities.lazy_import('pulumi_aws.glue')
    grafana = _utilities.lazy_import('pulumi_aws.grafana')
    guardduty = _utilities.lazy_import('pulumi_aws.guardduty')
    iam = _utilities.lazy_import('pulumi_aws.iam')
    identitystore = _utilities.lazy_import('pulumi_aws.identitystore')
    imagebuilder = _utilities.lazy_import('pulumi_aws.imagebuilder')
    inspector = _utilities.lazy_import('pulumi_aws.inspector')
    iot = _utilities.lazy_import('pulumi_aws.iot')
    kinesis = _utilities.lazy_import('pulumi_aws.kinesis')
    kinesisanalyticsv2 = _utilities.lazy_import('pulumi_aws.kinesisanalyticsv2')
    kms = _utilities.lazy_import('pulumi_aws.kms')
    lakeformation = _utilities.lazy_import('pulumi_aws.lakeformation')
    lambda_ = _utilities.lazy_import('pulumi_aws.lambda_')
    lb = _utilities.lazy_import('pulumi_aws.lb')
    lex = _utilities.lazy_import('pulumi_aws.lex')
    licensemanager = _utilities.lazy_import('pulumi_aws.licensemanager')
    lightsail = _utilities.lazy_import('pulumi_aws.lightsail')
    macie = _utilities.lazy_import('pulumi_aws.macie')
    macie2 = _utilities.lazy_import('pulumi_aws.macie2')
    mediaconvert = _utilities.lazy_import('pulumi_aws.mediaconvert')
    mediapackage = _utilities.lazy_import('pulumi_aws.mediapackage')
    mediastore = _utilities.lazy_import('pulumi_aws.mediastore')
    memorydb = _utilities.lazy_import('pulumi_aws.memorydb')
    mq = _utilities.lazy_import('pulumi_aws.mq')
    msk = _utilities.lazy_import('pulumi_aws.msk')
    mskconnect = _utilities.lazy_import('pulumi_aws.mskconnect')
    mwaa = _utilities.lazy_import('pulumi_aws.mwaa')
    neptune = _utilities.lazy_import('pulumi_aws.neptune')
    networkfirewall = _utilities.lazy_import('pulumi_aws.networkfirewall')
    networkmanager = _utilities.lazy_import('pulumi_aws.networkmanager')
    opsworks = _utilities.lazy_import('pulumi_aws.opsworks')
    organizations = _utilities.lazy_import('pulumi_aws.organizations')
    outposts = _utilities.lazy_import('pulumi_aws.outposts')
    pinpoint = _utilities.lazy_import('pulumi_aws.pinpoint')
    pricing = _utilities.lazy_import('pulumi_aws.pricing')
    qldb = _utilities.lazy_import('pulumi_aws.qldb')
    quicksight = _utilities.lazy_import('pulumi_aws.quicksight')
    ram = _utilities.lazy_import('pulumi_aws.ram')
    rds = _utilities.lazy_import('pulumi_aws.rds')
    redshift = _utilities.lazy_import('pulumi_aws.redshift')
    resourcegroups = _utilities.lazy_import('pulumi_aws.resourcegroups')
    resourcegroupstaggingapi = _utilities.lazy_import('pulumi_aws.resourcegroupstaggingapi')
    route53 = _utilities.lazy_import('pulumi_aws.route53')
    route53domains = _utilities.lazy_import('pulumi_aws.route53domains')
    route53recoverycontrol = _utilities.lazy_import('pulumi_aws.route53recoverycontrol')
    route53recoveryreadiness = _utilities.lazy_import('pulumi_aws.route53recoveryreadiness')
    s3 = _utilities.lazy_import('pulumi_aws.s3')
    s3control = _utilities.lazy_import('pulumi_aws.s3control')
    s3outposts = _utilities.lazy_import('pulumi_aws.s3outposts')
    sagemaker = _utilities.lazy_import('pulumi_aws.sagemaker')
    schemas = _utilities.lazy_import('pulumi_aws.schemas')
    secretsmanager = _utilities.lazy_import('pulumi_aws.secretsmanager')
    securityhub = _utilities.lazy_import('pulumi_aws.securityhub')
    serverlessrepository = _utilities.lazy_import('pulumi_aws.serverlessrepository')
    servicecatalog = _utilities.lazy_import('pulumi_aws.servicecatalog')
    servicediscovery = _utilities.lazy_import('pulumi_aws.servicediscovery')
    servicequotas = _utilities.lazy_import('pulumi_aws.servicequotas')
    ses = _utilities.lazy_import('pulumi_aws.ses')
    sfn = _utilities.lazy_import('pulumi_aws.sfn')
    shield = _utilities.lazy_import('pulumi_aws.shield')
    signer = _utilities.lazy_import('pulumi_aws.signer')
    simpledb = _utilities.lazy_import('pulumi_aws.simpledb')
    sns = _utilities.lazy_import('pulumi_aws.sns')
    sqs = _utilities.lazy_import('pulumi_aws.sqs')
    ssm = _utilities.lazy_import('pulumi_aws.ssm')
    ssoadmin = _utilities.lazy_import('pulumi_aws.ssoadmin')
    storagegateway = _utilities.lazy_import('pulumi_aws.storagegateway')
    swf = _utilities.lazy_import('pulumi_aws.swf')
    synthetics = _utilities.lazy_import('pulumi_aws.synthetics')
    timestreamwrite = _utilities.lazy_import('pulumi_aws.timestreamwrite')
    transfer = _utilities.lazy_import('pulumi_aws.transfer')
    waf = _utilities.lazy_import('pulumi_aws.waf')
    wafregional = _utilities.lazy_import('pulumi_aws.wafregional')
    wafv2 = _utilities.lazy_import('pulumi_aws.wafv2')
    worklink = _utilities.lazy_import('pulumi_aws.worklink')
    workspaces = _utilities.lazy_import('pulumi_aws.workspaces')
    xray = _utilities.lazy_import('pulumi_aws.xray')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "aws",
  "mod": "accessanalyzer/analyzer",
  "fqn": "pulumi_aws.accessanalyzer",
  "classes": {
   "aws:accessanalyzer/analyzer:Analyzer": "Analyzer"
  }
 },
 {
  "pkg": "aws",
  "mod": "account/alternativeContact",
  "fqn": "pulumi_aws.account",
  "classes": {
   "aws:account/alternativeContact:AlternativeContact": "AlternativeContact"
  }
 },
 {
  "pkg": "aws",
  "mod": "acm/certificate",
  "fqn": "pulumi_aws.acm",
  "classes": {
   "aws:acm/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "acm/certificateValidation",
  "fqn": "pulumi_aws.acm",
  "classes": {
   "aws:acm/certificateValidation:CertificateValidation": "CertificateValidation"
  }
 },
 {
  "pkg": "aws",
  "mod": "acmpca/certificate",
  "fqn": "pulumi_aws.acmpca",
  "classes": {
   "aws:acmpca/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "acmpca/certificateAuthority",
  "fqn": "pulumi_aws.acmpca",
  "classes": {
   "aws:acmpca/certificateAuthority:CertificateAuthority": "CertificateAuthority"
  }
 },
 {
  "pkg": "aws",
  "mod": "acmpca/certificateAuthorityCertificate",
  "fqn": "pulumi_aws.acmpca",
  "classes": {
   "aws:acmpca/certificateAuthorityCertificate:CertificateAuthorityCertificate": "CertificateAuthorityCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/listener",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/listenerCertificate",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/listenerCertificate:ListenerCertificate": "ListenerCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/listenerRule",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/listenerRule:ListenerRule": "ListenerRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/loadBalancer",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/targetGroup",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/targetGroup:TargetGroup": "TargetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "alb/targetGroupAttachment",
  "fqn": "pulumi_aws.alb",
  "classes": {
   "aws:alb/targetGroupAttachment:TargetGroupAttachment": "TargetGroupAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "amp/alertManagerDefinition",
  "fqn": "pulumi_aws.amp",
  "classes": {
   "aws:amp/alertManagerDefinition:AlertManagerDefinition": "AlertManagerDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "amp/ruleGroupNamespace",
  "fqn": "pulumi_aws.amp",
  "classes": {
   "aws:amp/ruleGroupNamespace:RuleGroupNamespace": "RuleGroupNamespace"
  }
 },
 {
  "pkg": "aws",
  "mod": "amp/workspace",
  "fqn": "pulumi_aws.amp",
  "classes": {
   "aws:amp/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "aws",
  "mod": "amplify/app",
  "fqn": "pulumi_aws.amplify",
  "classes": {
   "aws:amplify/app:App": "App"
  }
 },
 {
  "pkg": "aws",
  "mod": "amplify/backendEnvironment",
  "fqn": "pulumi_aws.amplify",
  "classes": {
   "aws:amplify/backendEnvironment:BackendEnvironment": "BackendEnvironment"
  }
 },
 {
  "pkg": "aws",
  "mod": "amplify/branch",
  "fqn": "pulumi_aws.amplify",
  "classes": {
   "aws:amplify/branch:Branch": "Branch"
  }
 },
 {
  "pkg": "aws",
  "mod": "amplify/domainAssociation",
  "fqn": "pulumi_aws.amplify",
  "classes": {
   "aws:amplify/domainAssociation:DomainAssociation": "DomainAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "amplify/webhook",
  "fqn": "pulumi_aws.amplify",
  "classes": {
   "aws:amplify/webhook:Webhook": "Webhook"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/account",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/account:Account": "Account"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/apiKey",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/authorizer",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/authorizer:Authorizer": "Authorizer"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/basePathMapping",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/basePathMapping:BasePathMapping": "BasePathMapping"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/clientCertificate",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/clientCertificate:ClientCertificate": "ClientCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/deployment",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/documentationPart",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/documentationPart:DocumentationPart": "DocumentationPart"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/documentationVersion",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/documentationVersion:DocumentationVersion": "DocumentationVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/domainName",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/domainName:DomainName": "DomainName"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/integration",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/integrationResponse",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/integrationResponse:IntegrationResponse": "IntegrationResponse"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/method",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/method:Method": "Method"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/methodResponse",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/methodResponse:MethodResponse": "MethodResponse"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/methodSettings",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/methodSettings:MethodSettings": "MethodSettings"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/model",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/model:Model": "Model"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/requestValidator",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/requestValidator:RequestValidator": "RequestValidator"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/resource",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/resource:Resource": "Resource"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/response",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/response:Response": "Response"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/restApi",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/restApi:RestApi": "RestApi"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/restApiPolicy",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/restApiPolicy:RestApiPolicy": "RestApiPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/stage",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/stage:Stage": "Stage"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/usagePlan",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/usagePlan:UsagePlan": "UsagePlan"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/usagePlanKey",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/usagePlanKey:UsagePlanKey": "UsagePlanKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigateway/vpcLink",
  "fqn": "pulumi_aws.apigateway",
  "classes": {
   "aws:apigateway/vpcLink:VpcLink": "VpcLink"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/api",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/api:Api": "Api"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/apiMapping",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/apiMapping:ApiMapping": "ApiMapping"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/authorizer",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/authorizer:Authorizer": "Authorizer"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/deployment",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/domainName",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/domainName:DomainName": "DomainName"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/integration",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/integrationResponse",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/integrationResponse:IntegrationResponse": "IntegrationResponse"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/model",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/model:Model": "Model"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/route",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/route:Route": "Route"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/routeResponse",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/routeResponse:RouteResponse": "RouteResponse"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/stage",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/stage:Stage": "Stage"
  }
 },
 {
  "pkg": "aws",
  "mod": "apigatewayv2/vpcLink",
  "fqn": "pulumi_aws.apigatewayv2",
  "classes": {
   "aws:apigatewayv2/vpcLink:VpcLink": "VpcLink"
  }
 },
 {
  "pkg": "aws",
  "mod": "appautoscaling/policy",
  "fqn": "pulumi_aws.appautoscaling",
  "classes": {
   "aws:appautoscaling/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "appautoscaling/scheduledAction",
  "fqn": "pulumi_aws.appautoscaling",
  "classes": {
   "aws:appautoscaling/scheduledAction:ScheduledAction": "ScheduledAction"
  }
 },
 {
  "pkg": "aws",
  "mod": "appautoscaling/target",
  "fqn": "pulumi_aws.appautoscaling",
  "classes": {
   "aws:appautoscaling/target:Target": "Target"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/application",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/application:Application": "Application"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/configurationProfile",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/configurationProfile:ConfigurationProfile": "ConfigurationProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/deployment",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/deploymentStrategy",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/deploymentStrategy:DeploymentStrategy": "DeploymentStrategy"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/environment",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "aws",
  "mod": "appconfig/hostedConfigurationVersion",
  "fqn": "pulumi_aws.appconfig",
  "classes": {
   "aws:appconfig/hostedConfigurationVersion:HostedConfigurationVersion": "HostedConfigurationVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/listener",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/listenerCertificate",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/listenerCertificate:ListenerCertificate": "ListenerCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/listenerRule",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/listenerRule:ListenerRule": "ListenerRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/loadBalancer",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/targetGroup",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/targetGroup:TargetGroup": "TargetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "applicationloadbalancing/targetGroupAttachment",
  "fqn": "pulumi_aws.applicationloadbalancing",
  "classes": {
   "aws:applicationloadbalancing/targetGroupAttachment:TargetGroupAttachment": "TargetGroupAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/gatewayRoute",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/gatewayRoute:GatewayRoute": "GatewayRoute"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/mesh",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/mesh:Mesh": "Mesh"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/route",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/route:Route": "Route"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/virtualGateway",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/virtualGateway:VirtualGateway": "VirtualGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/virtualNode",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/virtualNode:VirtualNode": "VirtualNode"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/virtualRouter",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/virtualRouter:VirtualRouter": "VirtualRouter"
  }
 },
 {
  "pkg": "aws",
  "mod": "appmesh/virtualService",
  "fqn": "pulumi_aws.appmesh",
  "classes": {
   "aws:appmesh/virtualService:VirtualService": "VirtualService"
  }
 },
 {
  "pkg": "aws",
  "mod": "apprunner/autoScalingConfigurationVersion",
  "fqn": "pulumi_aws.apprunner",
  "classes": {
   "aws:apprunner/autoScalingConfigurationVersion:AutoScalingConfigurationVersion": "AutoScalingConfigurationVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "apprunner/connection",
  "fqn": "pulumi_aws.apprunner",
  "classes": {
   "aws:apprunner/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "aws",
  "mod": "apprunner/customDomainAssociation",
  "fqn": "pulumi_aws.apprunner",
  "classes": {
   "aws:apprunner/customDomainAssociation:CustomDomainAssociation": "CustomDomainAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "apprunner/service",
  "fqn": "pulumi_aws.apprunner",
  "classes": {
   "aws:apprunner/service:Service": "Service"
  }
 },
 {
  "pkg": "aws",
  "mod": "apprunner/vpcConnector",
  "fqn": "pulumi_aws.apprunner",
  "classes": {
   "aws:apprunner/vpcConnector:VpcConnector": "VpcConnector"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/directoryConfig",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/directoryConfig:DirectoryConfig": "DirectoryConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/fleet",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/fleet:Fleet": "Fleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/fleetStackAssociation",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/fleetStackAssociation:FleetStackAssociation": "FleetStackAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/imageBuilder",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/imageBuilder:ImageBuilder": "ImageBuilder"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/stack",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/stack:Stack": "Stack"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/user",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "appstream/userStackAssociation",
  "fqn": "pulumi_aws.appstream",
  "classes": {
   "aws:appstream/userStackAssociation:UserStackAssociation": "UserStackAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/apiCache",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/apiCache:ApiCache": "ApiCache"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/apiKey",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/dataSource",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/dataSource:DataSource": "DataSource"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/domainName",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/domainName:DomainName": "DomainName"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/domainNameApiAssociation",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/domainNameApiAssociation:DomainNameApiAssociation": "DomainNameApiAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/function",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/function:Function": "Function"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/graphQLApi",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/graphQLApi:GraphQLApi": "GraphQLApi"
  }
 },
 {
  "pkg": "aws",
  "mod": "appsync/resolver",
  "fqn": "pulumi_aws.appsync",
  "classes": {
   "aws:appsync/resolver:Resolver": "Resolver"
  }
 },
 {
  "pkg": "aws",
  "mod": "athena/database",
  "fqn": "pulumi_aws.athena",
  "classes": {
   "aws:athena/database:Database": "Database"
  }
 },
 {
  "pkg": "aws",
  "mod": "athena/namedQuery",
  "fqn": "pulumi_aws.athena",
  "classes": {
   "aws:athena/namedQuery:NamedQuery": "NamedQuery"
  }
 },
 {
  "pkg": "aws",
  "mod": "athena/workgroup",
  "fqn": "pulumi_aws.athena",
  "classes": {
   "aws:athena/workgroup:Workgroup": "Workgroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/attachment",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/attachment:Attachment": "Attachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/group",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/group:Group": "Group"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/lifecycleHook",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/lifecycleHook:LifecycleHook": "LifecycleHook"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/notification",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/notification:Notification": "Notification"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/policy",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/schedule",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscaling/tag",
  "fqn": "pulumi_aws.autoscaling",
  "classes": {
   "aws:autoscaling/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "aws",
  "mod": "autoscalingplans/scalingPlan",
  "fqn": "pulumi_aws.autoscalingplans",
  "classes": {
   "aws:autoscalingplans/scalingPlan:ScalingPlan": "ScalingPlan"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/framework",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/framework:Framework": "Framework"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/globalSettings",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/globalSettings:GlobalSettings": "GlobalSettings"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/plan",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/plan:Plan": "Plan"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/regionSettings",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/regionSettings:RegionSettings": "RegionSettings"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/reportPlan",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/reportPlan:ReportPlan": "ReportPlan"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/selection",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/selection:Selection": "Selection"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/vault",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/vaultLockConfiguration",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/vaultLockConfiguration:VaultLockConfiguration": "VaultLockConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/vaultNotifications",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/vaultNotifications:VaultNotifications": "VaultNotifications"
  }
 },
 {
  "pkg": "aws",
  "mod": "backup/vaultPolicy",
  "fqn": "pulumi_aws.backup",
  "classes": {
   "aws:backup/vaultPolicy:VaultPolicy": "VaultPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "batch/computeEnvironment",
  "fqn": "pulumi_aws.batch",
  "classes": {
   "aws:batch/computeEnvironment:ComputeEnvironment": "ComputeEnvironment"
  }
 },
 {
  "pkg": "aws",
  "mod": "batch/jobDefinition",
  "fqn": "pulumi_aws.batch",
  "classes": {
   "aws:batch/jobDefinition:JobDefinition": "JobDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "batch/jobQueue",
  "fqn": "pulumi_aws.batch",
  "classes": {
   "aws:batch/jobQueue:JobQueue": "JobQueue"
  }
 },
 {
  "pkg": "aws",
  "mod": "batch/schedulingPolicy",
  "fqn": "pulumi_aws.batch",
  "classes": {
   "aws:batch/schedulingPolicy:SchedulingPolicy": "SchedulingPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "budgets/budget",
  "fqn": "pulumi_aws.budgets",
  "classes": {
   "aws:budgets/budget:Budget": "Budget"
  }
 },
 {
  "pkg": "aws",
  "mod": "budgets/budgetAction",
  "fqn": "pulumi_aws.budgets",
  "classes": {
   "aws:budgets/budgetAction:BudgetAction": "BudgetAction"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/aggregateAuthorization",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/aggregateAuthorization:AggregateAuthorization": "AggregateAuthorization"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/configurationAggregator",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/configurationAggregator:ConfigurationAggregator": "ConfigurationAggregator"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/conformancePack",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/conformancePack:ConformancePack": "ConformancePack"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/deliveryChannel",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/deliveryChannel:DeliveryChannel": "DeliveryChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/organizationConformancePack",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/organizationConformancePack:OrganizationConformancePack": "OrganizationConformancePack"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/organizationCustomRule",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/organizationCustomRule:OrganizationCustomRule": "OrganizationCustomRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/organizationManagedRule",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/organizationManagedRule:OrganizationManagedRule": "OrganizationManagedRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/recorder",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/recorder:Recorder": "Recorder"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/recorderStatus",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/recorderStatus:RecorderStatus": "RecorderStatus"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/remediationConfiguration",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/remediationConfiguration:RemediationConfiguration": "RemediationConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "cfg/rule",
  "fqn": "pulumi_aws.cfg",
  "classes": {
   "aws:cfg/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnector",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnector:VoiceConnector": "VoiceConnector"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorGroup",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorGroup:VoiceConnectorGroup": "VoiceConnectorGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorLogging",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorLogging:VoiceConnectorLogging": "VoiceConnectorLogging"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorOrganization",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorOrganization:VoiceConnectorOrganization": "VoiceConnectorOrganization"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorStreaming",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorStreaming:VoiceConnectorStreaming": "VoiceConnectorStreaming"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorTermination",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorTermination:VoiceConnectorTermination": "VoiceConnectorTermination"
  }
 },
 {
  "pkg": "aws",
  "mod": "chime/voiceConnectorTerminationCredentials",
  "fqn": "pulumi_aws.chime",
  "classes": {
   "aws:chime/voiceConnectorTerminationCredentials:VoiceConnectorTerminationCredentials": "VoiceConnectorTerminationCredentials"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloud9/environmentEC2",
  "fqn": "pulumi_aws.cloud9",
  "classes": {
   "aws:cloud9/environmentEC2:EnvironmentEC2": "EnvironmentEC2"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloud9/environmentMembership",
  "fqn": "pulumi_aws.cloud9",
  "classes": {
   "aws:cloud9/environmentMembership:EnvironmentMembership": "EnvironmentMembership"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudcontrol/resource",
  "fqn": "pulumi_aws.cloudcontrol",
  "classes": {
   "aws:cloudcontrol/resource:Resource": "Resource"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudformation/cloudFormationType",
  "fqn": "pulumi_aws.cloudformation",
  "classes": {
   "aws:cloudformation/cloudFormationType:CloudFormationType": "CloudFormationType"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudformation/stack",
  "fqn": "pulumi_aws.cloudformation",
  "classes": {
   "aws:cloudformation/stack:Stack": "Stack"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudformation/stackSet",
  "fqn": "pulumi_aws.cloudformation",
  "classes": {
   "aws:cloudformation/stackSet:StackSet": "StackSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudformation/stackSetInstance",
  "fqn": "pulumi_aws.cloudformation",
  "classes": {
   "aws:cloudformation/stackSetInstance:StackSetInstance": "StackSetInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/cachePolicy",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/cachePolicy:CachePolicy": "CachePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/distribution",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/distribution:Distribution": "Distribution"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/fieldLevelEncryptionConfig",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/fieldLevelEncryptionConfig:FieldLevelEncryptionConfig": "FieldLevelEncryptionConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/fieldLevelEncryptionProfile",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/fieldLevelEncryptionProfile:FieldLevelEncryptionProfile": "FieldLevelEncryptionProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/function",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/function:Function": "Function"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/keyGroup",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/keyGroup:KeyGroup": "KeyGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/monitoringSubscription",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/monitoringSubscription:MonitoringSubscription": "MonitoringSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/originAccessIdentity",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/originAccessIdentity:OriginAccessIdentity": "OriginAccessIdentity"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/originRequestPolicy",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/originRequestPolicy:OriginRequestPolicy": "OriginRequestPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/publicKey",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/publicKey:PublicKey": "PublicKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/realtimeLogConfig",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/realtimeLogConfig:RealtimeLogConfig": "RealtimeLogConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudfront/responseHeadersPolicy",
  "fqn": "pulumi_aws.cloudfront",
  "classes": {
   "aws:cloudfront/responseHeadersPolicy:ResponseHeadersPolicy": "ResponseHeadersPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudhsmv2/cluster",
  "fqn": "pulumi_aws.cloudhsmv2",
  "classes": {
   "aws:cloudhsmv2/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudhsmv2/hsm",
  "fqn": "pulumi_aws.cloudhsmv2",
  "classes": {
   "aws:cloudhsmv2/hsm:Hsm": "Hsm"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudsearch/domain",
  "fqn": "pulumi_aws.cloudsearch",
  "classes": {
   "aws:cloudsearch/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudsearch/domainServiceAccessPolicy",
  "fqn": "pulumi_aws.cloudsearch",
  "classes": {
   "aws:cloudsearch/domainServiceAccessPolicy:DomainServiceAccessPolicy": "DomainServiceAccessPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudtrail/eventDataStore",
  "fqn": "pulumi_aws.cloudtrail",
  "classes": {
   "aws:cloudtrail/eventDataStore:EventDataStore": "EventDataStore"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudtrail/trail",
  "fqn": "pulumi_aws.cloudtrail",
  "classes": {
   "aws:cloudtrail/trail:Trail": "Trail"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/compositeAlarm",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/compositeAlarm:CompositeAlarm": "CompositeAlarm"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/dashboard",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventApiDestination",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventApiDestination:EventApiDestination": "EventApiDestination"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventArchive",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventArchive:EventArchive": "EventArchive"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventBus",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventBus:EventBus": "EventBus"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventBusPolicy",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventBusPolicy:EventBusPolicy": "EventBusPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventConnection",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventConnection:EventConnection": "EventConnection"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventPermission",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventPermission:EventPermission": "EventPermission"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventRule",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventRule:EventRule": "EventRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/eventTarget",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/eventTarget:EventTarget": "EventTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logDestination",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logDestination:LogDestination": "LogDestination"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logDestinationPolicy",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logDestinationPolicy:LogDestinationPolicy": "LogDestinationPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logGroup",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logGroup:LogGroup": "LogGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logMetricFilter",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logMetricFilter:LogMetricFilter": "LogMetricFilter"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logResourcePolicy",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logResourcePolicy:LogResourcePolicy": "LogResourcePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logStream",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logStream:LogStream": "LogStream"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/logSubscriptionFilter",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/logSubscriptionFilter:LogSubscriptionFilter": "LogSubscriptionFilter"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/metricAlarm",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/metricAlarm:MetricAlarm": "MetricAlarm"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/metricStream",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/metricStream:MetricStream": "MetricStream"
  }
 },
 {
  "pkg": "aws",
  "mod": "cloudwatch/queryDefinition",
  "fqn": "pulumi_aws.cloudwatch",
  "classes": {
   "aws:cloudwatch/queryDefinition:QueryDefinition": "QueryDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "codeartifact/domain",
  "fqn": "pulumi_aws.codeartifact",
  "classes": {
   "aws:codeartifact/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "codeartifact/domainPermissions",
  "fqn": "pulumi_aws.codeartifact",
  "classes": {
   "aws:codeartifact/domainPermissions:DomainPermissions": "DomainPermissions"
  }
 },
 {
  "pkg": "aws",
  "mod": "codeartifact/repository",
  "fqn": "pulumi_aws.codeartifact",
  "classes": {
   "aws:codeartifact/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "aws",
  "mod": "codeartifact/repositoryPermissionsPolicy",
  "fqn": "pulumi_aws.codeartifact",
  "classes": {
   "aws:codeartifact/repositoryPermissionsPolicy:RepositoryPermissionsPolicy": "RepositoryPermissionsPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "codebuild/project",
  "fqn": "pulumi_aws.codebuild",
  "classes": {
   "aws:codebuild/project:Project": "Project"
  }
 },
 {
  "pkg": "aws",
  "mod": "codebuild/reportGroup",
  "fqn": "pulumi_aws.codebuild",
  "classes": {
   "aws:codebuild/reportGroup:ReportGroup": "ReportGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "codebuild/resourcePolicy",
  "fqn": "pulumi_aws.codebuild",
  "classes": {
   "aws:codebuild/resourcePolicy:ResourcePolicy": "ResourcePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "codebuild/sourceCredential",
  "fqn": "pulumi_aws.codebuild",
  "classes": {
   "aws:codebuild/sourceCredential:SourceCredential": "SourceCredential"
  }
 },
 {
  "pkg": "aws",
  "mod": "codebuild/webhook",
  "fqn": "pulumi_aws.codebuild",
  "classes": {
   "aws:codebuild/webhook:Webhook": "Webhook"
  }
 },
 {
  "pkg": "aws",
  "mod": "codecommit/approvalRuleTemplate",
  "fqn": "pulumi_aws.codecommit",
  "classes": {
   "aws:codecommit/approvalRuleTemplate:ApprovalRuleTemplate": "ApprovalRuleTemplate"
  }
 },
 {
  "pkg": "aws",
  "mod": "codecommit/approvalRuleTemplateAssociation",
  "fqn": "pulumi_aws.codecommit",
  "classes": {
   "aws:codecommit/approvalRuleTemplateAssociation:ApprovalRuleTemplateAssociation": "ApprovalRuleTemplateAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "codecommit/repository",
  "fqn": "pulumi_aws.codecommit",
  "classes": {
   "aws:codecommit/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "aws",
  "mod": "codecommit/trigger",
  "fqn": "pulumi_aws.codecommit",
  "classes": {
   "aws:codecommit/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "aws",
  "mod": "codedeploy/application",
  "fqn": "pulumi_aws.codedeploy",
  "classes": {
   "aws:codedeploy/application:Application": "Application"
  }
 },
 {
  "pkg": "aws",
  "mod": "codedeploy/deploymentConfig",
  "fqn": "pulumi_aws.codedeploy",
  "classes": {
   "aws:codedeploy/deploymentConfig:DeploymentConfig": "DeploymentConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "codedeploy/deploymentGroup",
  "fqn": "pulumi_aws.codedeploy",
  "classes": {
   "aws:codedeploy/deploymentGroup:DeploymentGroup": "DeploymentGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "codepipeline/pipeline",
  "fqn": "pulumi_aws.codepipeline",
  "classes": {
   "aws:codepipeline/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "aws",
  "mod": "codepipeline/webhook",
  "fqn": "pulumi_aws.codepipeline",
  "classes": {
   "aws:codepipeline/webhook:Webhook": "Webhook"
  }
 },
 {
  "pkg": "aws",
  "mod": "codestarconnections/connection",
  "fqn": "pulumi_aws.codestarconnections",
  "classes": {
   "aws:codestarconnections/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "aws",
  "mod": "codestarconnections/host",
  "fqn": "pulumi_aws.codestarconnections",
  "classes": {
   "aws:codestarconnections/host:Host": "Host"
  }
 },
 {
  "pkg": "aws",
  "mod": "codestarnotifications/notificationRule",
  "fqn": "pulumi_aws.codestarnotifications",
  "classes": {
   "aws:codestarnotifications/notificationRule:NotificationRule": "NotificationRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/identityPool",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/identityPool:IdentityPool": "IdentityPool"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/identityPoolProviderPrincipalTag",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/identityPoolProviderPrincipalTag:IdentityPoolProviderPrincipalTag": "IdentityPoolProviderPrincipalTag"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/identityPoolRoleAttachment",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/identityPoolRoleAttachment:IdentityPoolRoleAttachment": "IdentityPoolRoleAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/identityProvider",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/resourceServer",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/resourceServer:ResourceServer": "ResourceServer"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/user",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/userGroup",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/userGroup:UserGroup": "UserGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/userPool",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/userPool:UserPool": "UserPool"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/userPoolClient",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/userPoolClient:UserPoolClient": "UserPoolClient"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/userPoolDomain",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/userPoolDomain:UserPoolDomain": "UserPoolDomain"
  }
 },
 {
  "pkg": "aws",
  "mod": "cognito/userPoolUICustomization",
  "fqn": "pulumi_aws.cognito",
  "classes": {
   "aws:cognito/userPoolUICustomization:UserPoolUICustomization": "UserPoolUICustomization"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/botAssociation",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/botAssociation:BotAssociation": "BotAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/contactFlow",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/contactFlow:ContactFlow": "ContactFlow"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/contactFlowModule",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/contactFlowModule:ContactFlowModule": "ContactFlowModule"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/hoursOfOperation",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/hoursOfOperation:HoursOfOperation": "HoursOfOperation"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/instance",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/lambdaFunctionAssociation",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/lambdaFunctionAssociation:LambdaFunctionAssociation": "LambdaFunctionAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/queue",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/quickConnect",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/quickConnect:QuickConnect": "QuickConnect"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/routingProfile",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/routingProfile:RoutingProfile": "RoutingProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/securityProfile",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/securityProfile:SecurityProfile": "SecurityProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "connect/userHierarchyStructure",
  "fqn": "pulumi_aws.connect",
  "classes": {
   "aws:connect/userHierarchyStructure:UserHierarchyStructure": "UserHierarchyStructure"
  }
 },
 {
  "pkg": "aws",
  "mod": "cur/reportDefinition",
  "fqn": "pulumi_aws.cur",
  "classes": {
   "aws:cur/reportDefinition:ReportDefinition": "ReportDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "dataexchange/dataSet",
  "fqn": "pulumi_aws.dataexchange",
  "classes": {
   "aws:dataexchange/dataSet:DataSet": "DataSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "dataexchange/revision",
  "fqn": "pulumi_aws.dataexchange",
  "classes": {
   "aws:dataexchange/revision:Revision": "Revision"
  }
 },
 {
  "pkg": "aws",
  "mod": "datapipeline/pipeline",
  "fqn": "pulumi_aws.datapipeline",
  "classes": {
   "aws:datapipeline/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "aws",
  "mod": "datapipeline/pipelineDefinition",
  "fqn": "pulumi_aws.datapipeline",
  "classes": {
   "aws:datapipeline/pipelineDefinition:PipelineDefinition": "PipelineDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/agent",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/agent:Agent": "Agent"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/efsLocation",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/efsLocation:EfsLocation": "EfsLocation"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/locationFsxLustre",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/locationFsxLustre:LocationFsxLustre": "LocationFsxLustre"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/locationFsxWindows",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/locationFsxWindows:LocationFsxWindows": "LocationFsxWindows"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/locationHdfs",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/locationHdfs:LocationHdfs": "LocationHdfs"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/locationSmb",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/locationSmb:LocationSmb": "LocationSmb"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/nfsLocation",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/nfsLocation:NfsLocation": "NfsLocation"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/s3Location",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/s3Location:S3Location": "S3Location"
  }
 },
 {
  "pkg": "aws",
  "mod": "datasync/task",
  "fqn": "pulumi_aws.datasync",
  "classes": {
   "aws:datasync/task:Task": "Task"
  }
 },
 {
  "pkg": "aws",
  "mod": "dax/cluster",
  "fqn": "pulumi_aws.dax",
  "classes": {
   "aws:dax/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "dax/parameterGroup",
  "fqn": "pulumi_aws.dax",
  "classes": {
   "aws:dax/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "dax/subnetGroup",
  "fqn": "pulumi_aws.dax",
  "classes": {
   "aws:dax/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "detective/graph",
  "fqn": "pulumi_aws.detective",
  "classes": {
   "aws:detective/graph:Graph": "Graph"
  }
 },
 {
  "pkg": "aws",
  "mod": "detective/invitationAccepter",
  "fqn": "pulumi_aws.detective",
  "classes": {
   "aws:detective/invitationAccepter:InvitationAccepter": "InvitationAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "detective/member",
  "fqn": "pulumi_aws.detective",
  "classes": {
   "aws:detective/member:Member": "Member"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/devicePool",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/devicePool:DevicePool": "DevicePool"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/instanceProfile",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/instanceProfile:InstanceProfile": "InstanceProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/networkProfile",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/networkProfile:NetworkProfile": "NetworkProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/project",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/project:Project": "Project"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/testGridProject",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/testGridProject:TestGridProject": "TestGridProject"
  }
 },
 {
  "pkg": "aws",
  "mod": "devicefarm/upload",
  "fqn": "pulumi_aws.devicefarm",
  "classes": {
   "aws:devicefarm/upload:Upload": "Upload"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/bgpPeer",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/bgpPeer:BgpPeer": "BgpPeer"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/connection",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/connectionAssociation",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/connectionAssociation:ConnectionAssociation": "ConnectionAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/connectionConfirmation",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/connectionConfirmation:ConnectionConfirmation": "ConnectionConfirmation"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/gateway",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/gatewayAssociation",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/gatewayAssociation:GatewayAssociation": "GatewayAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/gatewayAssociationProposal",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/gatewayAssociationProposal:GatewayAssociationProposal": "GatewayAssociationProposal"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedConnection",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedConnection:HostedConnection": "HostedConnection"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedPrivateVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedPrivateVirtualInterface:HostedPrivateVirtualInterface": "HostedPrivateVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedPrivateVirtualInterfaceAccepter",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedPrivateVirtualInterfaceAccepter:HostedPrivateVirtualInterfaceAccepter": "HostedPrivateVirtualInterfaceAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedPublicVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedPublicVirtualInterface:HostedPublicVirtualInterface": "HostedPublicVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedPublicVirtualInterfaceAccepter",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedPublicVirtualInterfaceAccepter:HostedPublicVirtualInterfaceAccepter": "HostedPublicVirtualInterfaceAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedTransitVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedTransitVirtualInterface:HostedTransitVirtualInterface": "HostedTransitVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/hostedTransitVirtualInterfaceAcceptor",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/hostedTransitVirtualInterfaceAcceptor:HostedTransitVirtualInterfaceAcceptor": "HostedTransitVirtualInterfaceAcceptor"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/linkAggregationGroup",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/linkAggregationGroup:LinkAggregationGroup": "LinkAggregationGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/privateVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/privateVirtualInterface:PrivateVirtualInterface": "PrivateVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/publicVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/publicVirtualInterface:PublicVirtualInterface": "PublicVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directconnect/transitVirtualInterface",
  "fqn": "pulumi_aws.directconnect",
  "classes": {
   "aws:directconnect/transitVirtualInterface:TransitVirtualInterface": "TransitVirtualInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "directoryservice/conditionalForwader",
  "fqn": "pulumi_aws.directoryservice",
  "classes": {
   "aws:directoryservice/conditionalForwader:ConditionalForwader": "ConditionalForwader"
  }
 },
 {
  "pkg": "aws",
  "mod": "directoryservice/directory",
  "fqn": "pulumi_aws.directoryservice",
  "classes": {
   "aws:directoryservice/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "aws",
  "mod": "directoryservice/logService",
  "fqn": "pulumi_aws.directoryservice",
  "classes": {
   "aws:directoryservice/logService:LogService": "LogService"
  }
 },
 {
  "pkg": "aws",
  "mod": "dlm/lifecyclePolicy",
  "fqn": "pulumi_aws.dlm",
  "classes": {
   "aws:dlm/lifecyclePolicy:LifecyclePolicy": "LifecyclePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/certificate",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/endpoint",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/eventSubscription",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/replicationInstance",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/replicationInstance:ReplicationInstance": "ReplicationInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/replicationSubnetGroup",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/replicationSubnetGroup:ReplicationSubnetGroup": "ReplicationSubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "dms/replicationTask",
  "fqn": "pulumi_aws.dms",
  "classes": {
   "aws:dms/replicationTask:ReplicationTask": "ReplicationTask"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/cluster",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/clusterInstance",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/clusterInstance:ClusterInstance": "ClusterInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/clusterParameterGroup",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/clusterParameterGroup:ClusterParameterGroup": "ClusterParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/clusterSnapshot",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/clusterSnapshot:ClusterSnapshot": "ClusterSnapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/globalCluster",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/globalCluster:GlobalCluster": "GlobalCluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "docdb/subnetGroup",
  "fqn": "pulumi_aws.docdb",
  "classes": {
   "aws:docdb/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "dynamodb/globalTable",
  "fqn": "pulumi_aws.dynamodb",
  "classes": {
   "aws:dynamodb/globalTable:GlobalTable": "GlobalTable"
  }
 },
 {
  "pkg": "aws",
  "mod": "dynamodb/kinesisStreamingDestination",
  "fqn": "pulumi_aws.dynamodb",
  "classes": {
   "aws:dynamodb/kinesisStreamingDestination:KinesisStreamingDestination": "KinesisStreamingDestination"
  }
 },
 {
  "pkg": "aws",
  "mod": "dynamodb/table",
  "fqn": "pulumi_aws.dynamodb",
  "classes": {
   "aws:dynamodb/table:Table": "Table"
  }
 },
 {
  "pkg": "aws",
  "mod": "dynamodb/tableItem",
  "fqn": "pulumi_aws.dynamodb",
  "classes": {
   "aws:dynamodb/tableItem:TableItem": "TableItem"
  }
 },
 {
  "pkg": "aws",
  "mod": "dynamodb/tag",
  "fqn": "pulumi_aws.dynamodb",
  "classes": {
   "aws:dynamodb/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/defaultKmsKey",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/defaultKmsKey:DefaultKmsKey": "DefaultKmsKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/encryptionByDefault",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/encryptionByDefault:EncryptionByDefault": "EncryptionByDefault"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/snapshot",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/snapshotCopy",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/snapshotCopy:SnapshotCopy": "SnapshotCopy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/snapshotImport",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/snapshotImport:SnapshotImport": "SnapshotImport"
  }
 },
 {
  "pkg": "aws",
  "mod": "ebs/volume",
  "fqn": "pulumi_aws.ebs",
  "classes": {
   "aws:ebs/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/ami",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/ami:Ami": "Ami"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/amiCopy",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/amiCopy:AmiCopy": "AmiCopy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/amiFromInstance",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/amiFromInstance:AmiFromInstance": "AmiFromInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/amiLaunchPermission",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/amiLaunchPermission:AmiLaunchPermission": "AmiLaunchPermission"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/availabilityZoneGroup",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/availabilityZoneGroup:AvailabilityZoneGroup": "AvailabilityZoneGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/capacityReservation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/capacityReservation:CapacityReservation": "CapacityReservation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/carrierGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/carrierGateway:CarrierGateway": "CarrierGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/customerGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/customerGateway:CustomerGateway": "CustomerGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/dedicatedHost",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/dedicatedHost:DedicatedHost": "DedicatedHost"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultNetworkAcl",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultNetworkAcl:DefaultNetworkAcl": "DefaultNetworkAcl"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultRouteTable",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultRouteTable:DefaultRouteTable": "DefaultRouteTable"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultSecurityGroup",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultSecurityGroup:DefaultSecurityGroup": "DefaultSecurityGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultSubnet",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultSubnet:DefaultSubnet": "DefaultSubnet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultVpc",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultVpc:DefaultVpc": "DefaultVpc"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/defaultVpcDhcpOptions",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/defaultVpcDhcpOptions:DefaultVpcDhcpOptions": "DefaultVpcDhcpOptions"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/egressOnlyInternetGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/egressOnlyInternetGateway:EgressOnlyInternetGateway": "EgressOnlyInternetGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/eip",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/eip:Eip": "Eip"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/eipAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/eipAssociation:EipAssociation": "EipAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/fleet",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/fleet:Fleet": "Fleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/flowLog",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/flowLog:FlowLog": "FlowLog"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/instance",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/internetGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/internetGateway:InternetGateway": "InternetGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/internetGatewayAttachment",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/internetGatewayAttachment:InternetGatewayAttachment": "InternetGatewayAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/keyPair",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/keyPair:KeyPair": "KeyPair"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/launchConfiguration",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/launchConfiguration:LaunchConfiguration": "LaunchConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/launchTemplate",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/launchTemplate:LaunchTemplate": "LaunchTemplate"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/localGatewayRoute",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/localGatewayRoute:LocalGatewayRoute": "LocalGatewayRoute"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/localGatewayRouteTableVpcAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/localGatewayRouteTableVpcAssociation:LocalGatewayRouteTableVpcAssociation": "LocalGatewayRouteTableVpcAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/mainRouteTableAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/mainRouteTableAssociation:MainRouteTableAssociation": "MainRouteTableAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/managedPrefixList",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/managedPrefixList:ManagedPrefixList": "ManagedPrefixList"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/managedPrefixListEntry",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/managedPrefixListEntry:ManagedPrefixListEntry": "ManagedPrefixListEntry"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/natGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkAcl",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkAcl:NetworkAcl": "NetworkAcl"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkAclAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkAclAssociation:NetworkAclAssociation": "NetworkAclAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkAclRule",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkAclRule:NetworkAclRule": "NetworkAclRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkInsightsPath",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkInsightsPath:NetworkInsightsPath": "NetworkInsightsPath"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkInterface",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkInterface:NetworkInterface": "NetworkInterface"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkInterfaceAttachment",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkInterfaceAttachment:NetworkInterfaceAttachment": "NetworkInterfaceAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/networkInterfaceSecurityGroupAttachment",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/networkInterfaceSecurityGroupAttachment:NetworkInterfaceSecurityGroupAttachment": "NetworkInterfaceSecurityGroupAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/peeringConnectionOptions",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/peeringConnectionOptions:PeeringConnectionOptions": "PeeringConnectionOptions"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/placementGroup",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/placementGroup:PlacementGroup": "PlacementGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/proxyProtocolPolicy",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/proxyProtocolPolicy:ProxyProtocolPolicy": "ProxyProtocolPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/route",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/route:Route": "Route"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/routeTable",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/routeTableAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/routeTableAssociation:RouteTableAssociation": "RouteTableAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/securityGroup",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/securityGroupAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/securityGroupAssociation:SecurityGroupAssociation": "SecurityGroupAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/securityGroupRule",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/securityGroupRule:SecurityGroupRule": "SecurityGroupRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/serialConsoleAccess",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/serialConsoleAccess:SerialConsoleAccess": "SerialConsoleAccess"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/snapshotCreateVolumePermission",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/snapshotCreateVolumePermission:SnapshotCreateVolumePermission": "SnapshotCreateVolumePermission"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/spotDatafeedSubscription",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/spotDatafeedSubscription:SpotDatafeedSubscription": "SpotDatafeedSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/spotFleetRequest",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/spotFleetRequest:SpotFleetRequest": "SpotFleetRequest"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/spotInstanceRequest",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/spotInstanceRequest:SpotInstanceRequest": "SpotInstanceRequest"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/subnet",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/subnetCidrReservation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/subnetCidrReservation:SubnetCidrReservation": "SubnetCidrReservation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/tag",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/trafficMirrorFilter",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/trafficMirrorFilter:TrafficMirrorFilter": "TrafficMirrorFilter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/trafficMirrorFilterRule",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/trafficMirrorFilterRule:TrafficMirrorFilterRule": "TrafficMirrorFilterRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/trafficMirrorSession",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/trafficMirrorSession:TrafficMirrorSession": "TrafficMirrorSession"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/trafficMirrorTarget",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/trafficMirrorTarget:TrafficMirrorTarget": "TrafficMirrorTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/transitGatewayPeeringAttachmentAccepter",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/transitGatewayPeeringAttachmentAccepter:TransitGatewayPeeringAttachmentAccepter": "TransitGatewayPeeringAttachmentAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/volumeAttachment",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/volumeAttachment:VolumeAttachment": "VolumeAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpc",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcDhcpOptions",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcDhcpOptions:VpcDhcpOptions": "VpcDhcpOptions"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcDhcpOptionsAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcDhcpOptionsAssociation:VpcDhcpOptionsAssociation": "VpcDhcpOptionsAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpoint",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpoint:VpcEndpoint": "VpcEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointConnectionAccepter",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointConnectionAccepter:VpcEndpointConnectionAccepter": "VpcEndpointConnectionAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointConnectionNotification",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointConnectionNotification:VpcEndpointConnectionNotification": "VpcEndpointConnectionNotification"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointPolicy",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointPolicy:VpcEndpointPolicy": "VpcEndpointPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointRouteTableAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointRouteTableAssociation:VpcEndpointRouteTableAssociation": "VpcEndpointRouteTableAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointService",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointService:VpcEndpointService": "VpcEndpointService"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointServiceAllowedPrinciple",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointServiceAllowedPrinciple:VpcEndpointServiceAllowedPrinciple": "VpcEndpointServiceAllowedPrinciple"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcEndpointSubnetAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcEndpointSubnetAssociation:VpcEndpointSubnetAssociation": "VpcEndpointSubnetAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpam",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpam:VpcIpam": "VpcIpam"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamOrganizationAdminAccount",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamOrganizationAdminAccount:VpcIpamOrganizationAdminAccount": "VpcIpamOrganizationAdminAccount"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamPool",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamPool:VpcIpamPool": "VpcIpamPool"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamPoolCidr",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamPoolCidr:VpcIpamPoolCidr": "VpcIpamPoolCidr"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamPoolCidrAllocation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamPoolCidrAllocation:VpcIpamPoolCidrAllocation": "VpcIpamPoolCidrAllocation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamPreviewNextCidr",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamPreviewNextCidr:VpcIpamPreviewNextCidr": "VpcIpamPreviewNextCidr"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpamScope",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpamScope:VpcIpamScope": "VpcIpamScope"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpv4CidrBlockAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpv4CidrBlockAssociation:VpcIpv4CidrBlockAssociation": "VpcIpv4CidrBlockAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcIpv6CidrBlockAssociation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcIpv6CidrBlockAssociation:VpcIpv6CidrBlockAssociation": "VpcIpv6CidrBlockAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcPeeringConnection",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcPeeringConnection:VpcPeeringConnection": "VpcPeeringConnection"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpcPeeringConnectionAccepter",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpcPeeringConnectionAccepter:VpcPeeringConnectionAccepter": "VpcPeeringConnectionAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpnConnection",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpnConnection:VpnConnection": "VpnConnection"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpnConnectionRoute",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpnConnectionRoute:VpnConnectionRoute": "VpnConnectionRoute"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpnGateway",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpnGateway:VpnGateway": "VpnGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpnGatewayAttachment",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpnGatewayAttachment:VpnGatewayAttachment": "VpnGatewayAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2/vpnGatewayRoutePropagation",
  "fqn": "pulumi_aws.ec2",
  "classes": {
   "aws:ec2/vpnGatewayRoutePropagation:VpnGatewayRoutePropagation": "VpnGatewayRoutePropagation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2clientvpn/authorizationRule",
  "fqn": "pulumi_aws.ec2clientvpn",
  "classes": {
   "aws:ec2clientvpn/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2clientvpn/endpoint",
  "fqn": "pulumi_aws.ec2clientvpn",
  "classes": {
   "aws:ec2clientvpn/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2clientvpn/networkAssociation",
  "fqn": "pulumi_aws.ec2clientvpn",
  "classes": {
   "aws:ec2clientvpn/networkAssociation:NetworkAssociation": "NetworkAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2clientvpn/route",
  "fqn": "pulumi_aws.ec2clientvpn",
  "classes": {
   "aws:ec2clientvpn/route:Route": "Route"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/connect",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/connect:Connect": "Connect"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/connectPeer",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/connectPeer:ConnectPeer": "ConnectPeer"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/multicastDomain",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/multicastDomain:MulticastDomain": "MulticastDomain"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/multicastDomainAssociation",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/multicastDomainAssociation:MulticastDomainAssociation": "MulticastDomainAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/multicastGroupMember",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/multicastGroupMember:MulticastGroupMember": "MulticastGroupMember"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/multicastGroupSource",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/multicastGroupSource:MulticastGroupSource": "MulticastGroupSource"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/peeringAttachment",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/peeringAttachment:PeeringAttachment": "PeeringAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/prefixListReference",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/prefixListReference:PrefixListReference": "PrefixListReference"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/route",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/route:Route": "Route"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/routeTable",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/routeTableAssociation",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/routeTableAssociation:RouteTableAssociation": "RouteTableAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/routeTablePropagation",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/routeTablePropagation:RouteTablePropagation": "RouteTablePropagation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/transitGateway",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/transitGateway:TransitGateway": "TransitGateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/vpcAttachment",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/vpcAttachment:VpcAttachment": "VpcAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ec2transitgateway/vpcAttachmentAccepter",
  "fqn": "pulumi_aws.ec2transitgateway",
  "classes": {
   "aws:ec2transitgateway/vpcAttachmentAccepter:VpcAttachmentAccepter": "VpcAttachmentAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/lifecyclePolicy",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/lifecyclePolicy:LifecyclePolicy": "LifecyclePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/pullThroughCacheRule",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/pullThroughCacheRule:PullThroughCacheRule": "PullThroughCacheRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/registryPolicy",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/registryPolicy:RegistryPolicy": "RegistryPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/registryScanningConfiguration",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/registryScanningConfiguration:RegistryScanningConfiguration": "RegistryScanningConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/replicationConfiguration",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/replicationConfiguration:ReplicationConfiguration": "ReplicationConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/repository",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecr/repositoryPolicy",
  "fqn": "pulumi_aws.ecr",
  "classes": {
   "aws:ecr/repositoryPolicy:RepositoryPolicy": "RepositoryPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecrpublic/repository",
  "fqn": "pulumi_aws.ecrpublic",
  "classes": {
   "aws:ecrpublic/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecrpublic/repositoryPolicy",
  "fqn": "pulumi_aws.ecrpublic",
  "classes": {
   "aws:ecrpublic/repositoryPolicy:RepositoryPolicy": "RepositoryPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/accountSettingDefault",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/accountSettingDefault:AccountSettingDefault": "AccountSettingDefault"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/capacityProvider",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/capacityProvider:CapacityProvider": "CapacityProvider"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/cluster",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/clusterCapacityProviders",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/clusterCapacityProviders:ClusterCapacityProviders": "ClusterCapacityProviders"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/service",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/service:Service": "Service"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/tag",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/taskDefinition",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/taskDefinition:TaskDefinition": "TaskDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "ecs/taskSet",
  "fqn": "pulumi_aws.ecs",
  "classes": {
   "aws:ecs/taskSet:TaskSet": "TaskSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "efs/accessPoint",
  "fqn": "pulumi_aws.efs",
  "classes": {
   "aws:efs/accessPoint:AccessPoint": "AccessPoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "efs/backupPolicy",
  "fqn": "pulumi_aws.efs",
  "classes": {
   "aws:efs/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "efs/fileSystem",
  "fqn": "pulumi_aws.efs",
  "classes": {
   "aws:efs/fileSystem:FileSystem": "FileSystem"
  }
 },
 {
  "pkg": "aws",
  "mod": "efs/fileSystemPolicy",
  "fqn": "pulumi_aws.efs",
  "classes": {
   "aws:efs/fileSystemPolicy:FileSystemPolicy": "FileSystemPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "efs/mountTarget",
  "fqn": "pulumi_aws.efs",
  "classes": {
   "aws:efs/mountTarget:MountTarget": "MountTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "eks/addon",
  "fqn": "pulumi_aws.eks",
  "classes": {
   "aws:eks/addon:Addon": "Addon"
  }
 },
 {
  "pkg": "aws",
  "mod": "eks/cluster",
  "fqn": "pulumi_aws.eks",
  "classes": {
   "aws:eks/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "eks/fargateProfile",
  "fqn": "pulumi_aws.eks",
  "classes": {
   "aws:eks/fargateProfile:FargateProfile": "FargateProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "eks/identityProviderConfig",
  "fqn": "pulumi_aws.eks",
  "classes": {
   "aws:eks/identityProviderConfig:IdentityProviderConfig": "IdentityProviderConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "eks/nodeGroup",
  "fqn": "pulumi_aws.eks",
  "classes": {
   "aws:eks/nodeGroup:NodeGroup": "NodeGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/cluster",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/globalReplicationGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/globalReplicationGroup:GlobalReplicationGroup": "GlobalReplicationGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/parameterGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/replicationGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/replicationGroup:ReplicationGroup": "ReplicationGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/securityGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/subnetGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/user",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticache/userGroup",
  "fqn": "pulumi_aws.elasticache",
  "classes": {
   "aws:elasticache/userGroup:UserGroup": "UserGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticbeanstalk/application",
  "fqn": "pulumi_aws.elasticbeanstalk",
  "classes": {
   "aws:elasticbeanstalk/application:Application": "Application"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticbeanstalk/applicationVersion",
  "fqn": "pulumi_aws.elasticbeanstalk",
  "classes": {
   "aws:elasticbeanstalk/applicationVersion:ApplicationVersion": "ApplicationVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticbeanstalk/configurationTemplate",
  "fqn": "pulumi_aws.elasticbeanstalk",
  "classes": {
   "aws:elasticbeanstalk/configurationTemplate:ConfigurationTemplate": "ConfigurationTemplate"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticbeanstalk/environment",
  "fqn": "pulumi_aws.elasticbeanstalk",
  "classes": {
   "aws:elasticbeanstalk/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/appCookieStickinessPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/appCookieStickinessPolicy:AppCookieStickinessPolicy": "AppCookieStickinessPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/attachment",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/attachment:Attachment": "Attachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/listenerPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/listenerPolicy:ListenerPolicy": "ListenerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/loadBalancer",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/loadBalancerBackendServerPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/loadBalancerBackendServerPolicy:LoadBalancerBackendServerPolicy": "LoadBalancerBackendServerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/loadBalancerCookieStickinessPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/loadBalancerCookieStickinessPolicy:LoadBalancerCookieStickinessPolicy": "LoadBalancerCookieStickinessPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/loadBalancerPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/loadBalancerPolicy:LoadBalancerPolicy": "LoadBalancerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancing/sslNegotiationPolicy",
  "fqn": "pulumi_aws.elasticloadbalancing",
  "classes": {
   "aws:elasticloadbalancing/sslNegotiationPolicy:SslNegotiationPolicy": "SslNegotiationPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/listener",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/listenerCertificate",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/listenerCertificate:ListenerCertificate": "ListenerCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/listenerRule",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/listenerRule:ListenerRule": "ListenerRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/loadBalancer",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/targetGroup",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/targetGroup:TargetGroup": "TargetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticloadbalancingv2/targetGroupAttachment",
  "fqn": "pulumi_aws.elasticloadbalancingv2",
  "classes": {
   "aws:elasticloadbalancingv2/targetGroupAttachment:TargetGroupAttachment": "TargetGroupAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticsearch/domain",
  "fqn": "pulumi_aws.elasticsearch",
  "classes": {
   "aws:elasticsearch/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticsearch/domainPolicy",
  "fqn": "pulumi_aws.elasticsearch",
  "classes": {
   "aws:elasticsearch/domainPolicy:DomainPolicy": "DomainPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elasticsearch/domainSamlOptions",
  "fqn": "pulumi_aws.elasticsearch",
  "classes": {
   "aws:elasticsearch/domainSamlOptions:DomainSamlOptions": "DomainSamlOptions"
  }
 },
 {
  "pkg": "aws",
  "mod": "elastictranscoder/pipeline",
  "fqn": "pulumi_aws.elastictranscoder",
  "classes": {
   "aws:elastictranscoder/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "aws",
  "mod": "elastictranscoder/preset",
  "fqn": "pulumi_aws.elastictranscoder",
  "classes": {
   "aws:elastictranscoder/preset:Preset": "Preset"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/appCookieStickinessPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/appCookieStickinessPolicy:AppCookieStickinessPolicy": "AppCookieStickinessPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/attachment",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/attachment:Attachment": "Attachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/listenerPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/listenerPolicy:ListenerPolicy": "ListenerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/loadBalancer",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/loadBalancerBackendServerPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/loadBalancerBackendServerPolicy:LoadBalancerBackendServerPolicy": "LoadBalancerBackendServerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/loadBalancerCookieStickinessPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/loadBalancerCookieStickinessPolicy:LoadBalancerCookieStickinessPolicy": "LoadBalancerCookieStickinessPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/loadBalancerPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/loadBalancerPolicy:LoadBalancerPolicy": "LoadBalancerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "elb/sslNegotiationPolicy",
  "fqn": "pulumi_aws.elb",
  "classes": {
   "aws:elb/sslNegotiationPolicy:SslNegotiationPolicy": "SslNegotiationPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/cluster",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/instanceFleet",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/instanceFleet:InstanceFleet": "InstanceFleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/instanceGroup",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/instanceGroup:InstanceGroup": "InstanceGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/managedScalingPolicy",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/managedScalingPolicy:ManagedScalingPolicy": "ManagedScalingPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/securityConfiguration",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/securityConfiguration:SecurityConfiguration": "SecurityConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/studio",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/studio:Studio": "Studio"
  }
 },
 {
  "pkg": "aws",
  "mod": "emr/studioSessionMapping",
  "fqn": "pulumi_aws.emr",
  "classes": {
   "aws:emr/studioSessionMapping:StudioSessionMapping": "StudioSessionMapping"
  }
 },
 {
  "pkg": "aws",
  "mod": "fms/adminAccount",
  "fqn": "pulumi_aws.fms",
  "classes": {
   "aws:fms/adminAccount:AdminAccount": "AdminAccount"
  }
 },
 {
  "pkg": "aws",
  "mod": "fms/policy",
  "fqn": "pulumi_aws.fms",
  "classes": {
   "aws:fms/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/backup",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/backup:Backup": "Backup"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/dataRepositoryAssociation",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/dataRepositoryAssociation:DataRepositoryAssociation": "DataRepositoryAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/lustreFileSystem",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/lustreFileSystem:LustreFileSystem": "LustreFileSystem"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/ontapFileSystem",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/ontapFileSystem:OntapFileSystem": "OntapFileSystem"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/ontapStorageVirtualMachine",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/ontapStorageVirtualMachine:OntapStorageVirtualMachine": "OntapStorageVirtualMachine"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/ontapVolume",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/ontapVolume:OntapVolume": "OntapVolume"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/openZfsFileSystem",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/openZfsFileSystem:OpenZfsFileSystem": "OpenZfsFileSystem"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/openZfsSnapshot",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/openZfsSnapshot:OpenZfsSnapshot": "OpenZfsSnapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/openZfsVolume",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/openZfsVolume:OpenZfsVolume": "OpenZfsVolume"
  }
 },
 {
  "pkg": "aws",
  "mod": "fsx/windowsFileSystem",
  "fqn": "pulumi_aws.fsx",
  "classes": {
   "aws:fsx/windowsFileSystem:WindowsFileSystem": "WindowsFileSystem"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/alias",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/build",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/build:Build": "Build"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/fleet",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/fleet:Fleet": "Fleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/gameServerGroup",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/gameServerGroup:GameServerGroup": "GameServerGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/gameSessionQueue",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/gameSessionQueue:GameSessionQueue": "GameSessionQueue"
  }
 },
 {
  "pkg": "aws",
  "mod": "gamelift/script",
  "fqn": "pulumi_aws.gamelift",
  "classes": {
   "aws:gamelift/script:Script": "Script"
  }
 },
 {
  "pkg": "aws",
  "mod": "glacier/vault",
  "fqn": "pulumi_aws.glacier",
  "classes": {
   "aws:glacier/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "aws",
  "mod": "glacier/vaultLock",
  "fqn": "pulumi_aws.glacier",
  "classes": {
   "aws:glacier/vaultLock:VaultLock": "VaultLock"
  }
 },
 {
  "pkg": "aws",
  "mod": "globalaccelerator/accelerator",
  "fqn": "pulumi_aws.globalaccelerator",
  "classes": {
   "aws:globalaccelerator/accelerator:Accelerator": "Accelerator"
  }
 },
 {
  "pkg": "aws",
  "mod": "globalaccelerator/endpointGroup",
  "fqn": "pulumi_aws.globalaccelerator",
  "classes": {
   "aws:globalaccelerator/endpointGroup:EndpointGroup": "EndpointGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "globalaccelerator/listener",
  "fqn": "pulumi_aws.globalaccelerator",
  "classes": {
   "aws:globalaccelerator/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/catalogDatabase",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/catalogDatabase:CatalogDatabase": "CatalogDatabase"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/catalogTable",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/catalogTable:CatalogTable": "CatalogTable"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/classifier",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/classifier:Classifier": "Classifier"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/connection",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/crawler",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/crawler:Crawler": "Crawler"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/dataCatalogEncryptionSettings",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/dataCatalogEncryptionSettings:DataCatalogEncryptionSettings": "DataCatalogEncryptionSettings"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/devEndpoint",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/devEndpoint:DevEndpoint": "DevEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/job",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/job:Job": "Job"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/mLTransform",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/mLTransform:MLTransform": "MLTransform"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/partition",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/partition:Partition": "Partition"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/partitionIndex",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/partitionIndex:PartitionIndex": "PartitionIndex"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/registry",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/resourcePolicy",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/resourcePolicy:ResourcePolicy": "ResourcePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/schema",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/securityConfiguration",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/securityConfiguration:SecurityConfiguration": "SecurityConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/trigger",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/userDefinedFunction",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/userDefinedFunction:UserDefinedFunction": "UserDefinedFunction"
  }
 },
 {
  "pkg": "aws",
  "mod": "glue/workflow",
  "fqn": "pulumi_aws.glue",
  "classes": {
   "aws:glue/workflow:Workflow": "Workflow"
  }
 },
 {
  "pkg": "aws",
  "mod": "grafana/licenseAssociation",
  "fqn": "pulumi_aws.grafana",
  "classes": {
   "aws:grafana/licenseAssociation:LicenseAssociation": "LicenseAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "grafana/workspace",
  "fqn": "pulumi_aws.grafana",
  "classes": {
   "aws:grafana/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "aws",
  "mod": "grafana/workspaceSamlConfiguration",
  "fqn": "pulumi_aws.grafana",
  "classes": {
   "aws:grafana/workspaceSamlConfiguration:WorkspaceSamlConfiguration": "WorkspaceSamlConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/detector",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/detector:Detector": "Detector"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/filter",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/filter:Filter": "Filter"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/iPSet",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/iPSet:IPSet": "IPSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/inviteAccepter",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/inviteAccepter:InviteAccepter": "InviteAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/member",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/member:Member": "Member"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/organizationAdminAccount",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/organizationAdminAccount:OrganizationAdminAccount": "OrganizationAdminAccount"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/organizationConfiguration",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/organizationConfiguration:OrganizationConfiguration": "OrganizationConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/publishingDestination",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/publishingDestination:PublishingDestination": "PublishingDestination"
  }
 },
 {
  "pkg": "aws",
  "mod": "guardduty/threatIntelSet",
  "fqn": "pulumi_aws.guardduty",
  "classes": {
   "aws:guardduty/threatIntelSet:ThreatIntelSet": "ThreatIntelSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/accessKey",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/accessKey:AccessKey": "AccessKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/accountAlias",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/accountAlias:AccountAlias": "AccountAlias"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/accountPasswordPolicy",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/accountPasswordPolicy:AccountPasswordPolicy": "AccountPasswordPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/group",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/group:Group": "Group"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/groupMembership",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/groupPolicy",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/groupPolicy:GroupPolicy": "GroupPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/groupPolicyAttachment",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/groupPolicyAttachment:GroupPolicyAttachment": "GroupPolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/instanceProfile",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/instanceProfile:InstanceProfile": "InstanceProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/openIdConnectProvider",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/openIdConnectProvider:OpenIdConnectProvider": "OpenIdConnectProvider"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/policy",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/policyAttachment",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/policyAttachment:PolicyAttachment": "PolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/role",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/role:Role": "Role"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/rolePolicy",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/rolePolicy:RolePolicy": "RolePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/rolePolicyAttachment",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/rolePolicyAttachment:RolePolicyAttachment": "RolePolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/samlProvider",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/samlProvider:SamlProvider": "SamlProvider"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/serverCertificate",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/serverCertificate:ServerCertificate": "ServerCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/serviceLinkedRole",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/serviceLinkedRole:ServiceLinkedRole": "ServiceLinkedRole"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/serviceSpecificCredential",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/serviceSpecificCredential:ServiceSpecificCredential": "ServiceSpecificCredential"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/signingCertificate",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/signingCertificate:SigningCertificate": "SigningCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/sshKey",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/user",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/userGroupMembership",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/userGroupMembership:UserGroupMembership": "UserGroupMembership"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/userLoginProfile",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/userLoginProfile:UserLoginProfile": "UserLoginProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/userPolicy",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/userPolicy:UserPolicy": "UserPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/userPolicyAttachment",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/userPolicyAttachment:UserPolicyAttachment": "UserPolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iam/virtualMfaDevice",
  "fqn": "pulumi_aws.iam",
  "classes": {
   "aws:iam/virtualMfaDevice:VirtualMfaDevice": "VirtualMfaDevice"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/component",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/component:Component": "Component"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/containerRecipe",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/containerRecipe:ContainerRecipe": "ContainerRecipe"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/distributionConfiguration",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/distributionConfiguration:DistributionConfiguration": "DistributionConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/image",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/image:Image": "Image"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/imagePipeline",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/imagePipeline:ImagePipeline": "ImagePipeline"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/imageRecipe",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/imageRecipe:ImageRecipe": "ImageRecipe"
  }
 },
 {
  "pkg": "aws",
  "mod": "imagebuilder/infrastructureConfiguration",
  "fqn": "pulumi_aws.imagebuilder",
  "classes": {
   "aws:imagebuilder/infrastructureConfiguration:InfrastructureConfiguration": "InfrastructureConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "inspector/assessmentTarget",
  "fqn": "pulumi_aws.inspector",
  "classes": {
   "aws:inspector/assessmentTarget:AssessmentTarget": "AssessmentTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "inspector/assessmentTemplate",
  "fqn": "pulumi_aws.inspector",
  "classes": {
   "aws:inspector/assessmentTemplate:AssessmentTemplate": "AssessmentTemplate"
  }
 },
 {
  "pkg": "aws",
  "mod": "inspector/resourceGroup",
  "fqn": "pulumi_aws.inspector",
  "classes": {
   "aws:inspector/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/authorizer",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/authorizer:Authorizer": "Authorizer"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/certificate",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/policy",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/policyAttachment",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/policyAttachment:PolicyAttachment": "PolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/roleAlias",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/roleAlias:RoleAlias": "RoleAlias"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/thing",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/thing:Thing": "Thing"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/thingGroup",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/thingGroup:ThingGroup": "ThingGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/thingGroupMembership",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/thingGroupMembership:ThingGroupMembership": "ThingGroupMembership"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/thingPrincipalAttachment",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/thingPrincipalAttachment:ThingPrincipalAttachment": "ThingPrincipalAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/thingType",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/thingType:ThingType": "ThingType"
  }
 },
 {
  "pkg": "aws",
  "mod": "iot/topicRule",
  "fqn": "pulumi_aws.iot",
  "classes": {
   "aws:iot/topicRule:TopicRule": "TopicRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesis/analyticsApplication",
  "fqn": "pulumi_aws.kinesis",
  "classes": {
   "aws:kinesis/analyticsApplication:AnalyticsApplication": "AnalyticsApplication"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesis/firehoseDeliveryStream",
  "fqn": "pulumi_aws.kinesis",
  "classes": {
   "aws:kinesis/firehoseDeliveryStream:FirehoseDeliveryStream": "FirehoseDeliveryStream"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesis/stream",
  "fqn": "pulumi_aws.kinesis",
  "classes": {
   "aws:kinesis/stream:Stream": "Stream"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesis/streamConsumer",
  "fqn": "pulumi_aws.kinesis",
  "classes": {
   "aws:kinesis/streamConsumer:StreamConsumer": "StreamConsumer"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesis/videoStream",
  "fqn": "pulumi_aws.kinesis",
  "classes": {
   "aws:kinesis/videoStream:VideoStream": "VideoStream"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesisanalyticsv2/application",
  "fqn": "pulumi_aws.kinesisanalyticsv2",
  "classes": {
   "aws:kinesisanalyticsv2/application:Application": "Application"
  }
 },
 {
  "pkg": "aws",
  "mod": "kinesisanalyticsv2/applicationSnapshot",
  "fqn": "pulumi_aws.kinesisanalyticsv2",
  "classes": {
   "aws:kinesisanalyticsv2/applicationSnapshot:ApplicationSnapshot": "ApplicationSnapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/alias",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/ciphertext",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/ciphertext:Ciphertext": "Ciphertext"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/externalKey",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/externalKey:ExternalKey": "ExternalKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/grant",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/grant:Grant": "Grant"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/key",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/key:Key": "Key"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/replicaExternalKey",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/replicaExternalKey:ReplicaExternalKey": "ReplicaExternalKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "kms/replicaKey",
  "fqn": "pulumi_aws.kms",
  "classes": {
   "aws:kms/replicaKey:ReplicaKey": "ReplicaKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "lakeformation/dataLakeSettings",
  "fqn": "pulumi_aws.lakeformation",
  "classes": {
   "aws:lakeformation/dataLakeSettings:DataLakeSettings": "DataLakeSettings"
  }
 },
 {
  "pkg": "aws",
  "mod": "lakeformation/permissions",
  "fqn": "pulumi_aws.lakeformation",
  "classes": {
   "aws:lakeformation/permissions:Permissions": "Permissions"
  }
 },
 {
  "pkg": "aws",
  "mod": "lakeformation/resource",
  "fqn": "pulumi_aws.lakeformation",
  "classes": {
   "aws:lakeformation/resource:Resource": "Resource"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/alias",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/codeSigningConfig",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/codeSigningConfig:CodeSigningConfig": "CodeSigningConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/eventSourceMapping",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/eventSourceMapping:EventSourceMapping": "EventSourceMapping"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/function",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/function:Function": "Function"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/functionEventInvokeConfig",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/functionEventInvokeConfig:FunctionEventInvokeConfig": "FunctionEventInvokeConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/invocation",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/invocation:Invocation": "Invocation"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/layerVersion",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/layerVersion:LayerVersion": "LayerVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/layerVersionPermission",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/layerVersionPermission:LayerVersionPermission": "LayerVersionPermission"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/permission",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/permission:Permission": "Permission"
  }
 },
 {
  "pkg": "aws",
  "mod": "lambda/provisionedConcurrencyConfig",
  "fqn": "pulumi_aws.lambda_",
  "classes": {
   "aws:lambda/provisionedConcurrencyConfig:ProvisionedConcurrencyConfig": "ProvisionedConcurrencyConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/listener",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/listenerCertificate",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/listenerCertificate:ListenerCertificate": "ListenerCertificate"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/listenerRule",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/listenerRule:ListenerRule": "ListenerRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/loadBalancer",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/targetGroup",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/targetGroup:TargetGroup": "TargetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "lb/targetGroupAttachment",
  "fqn": "pulumi_aws.lb",
  "classes": {
   "aws:lb/targetGroupAttachment:TargetGroupAttachment": "TargetGroupAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "lex/bot",
  "fqn": "pulumi_aws.lex",
  "classes": {
   "aws:lex/bot:Bot": "Bot"
  }
 },
 {
  "pkg": "aws",
  "mod": "lex/botAlias",
  "fqn": "pulumi_aws.lex",
  "classes": {
   "aws:lex/botAlias:BotAlias": "BotAlias"
  }
 },
 {
  "pkg": "aws",
  "mod": "lex/intent",
  "fqn": "pulumi_aws.lex",
  "classes": {
   "aws:lex/intent:Intent": "Intent"
  }
 },
 {
  "pkg": "aws",
  "mod": "lex/slotType",
  "fqn": "pulumi_aws.lex",
  "classes": {
   "aws:lex/slotType:SlotType": "SlotType"
  }
 },
 {
  "pkg": "aws",
  "mod": "licensemanager/association",
  "fqn": "pulumi_aws.licensemanager",
  "classes": {
   "aws:licensemanager/association:Association": "Association"
  }
 },
 {
  "pkg": "aws",
  "mod": "licensemanager/licenseConfiguration",
  "fqn": "pulumi_aws.licensemanager",
  "classes": {
   "aws:licensemanager/licenseConfiguration:LicenseConfiguration": "LicenseConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/domain",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/instance",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/instancePublicPorts",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/instancePublicPorts:InstancePublicPorts": "InstancePublicPorts"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/keyPair",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/keyPair:KeyPair": "KeyPair"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/staticIp",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/staticIp:StaticIp": "StaticIp"
  }
 },
 {
  "pkg": "aws",
  "mod": "lightsail/staticIpAttachment",
  "fqn": "pulumi_aws.lightsail",
  "classes": {
   "aws:lightsail/staticIpAttachment:StaticIpAttachment": "StaticIpAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie/customDataIdentifier",
  "fqn": "pulumi_aws.macie",
  "classes": {
   "aws:macie/customDataIdentifier:CustomDataIdentifier": "CustomDataIdentifier"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie/findingsFilter",
  "fqn": "pulumi_aws.macie",
  "classes": {
   "aws:macie/findingsFilter:FindingsFilter": "FindingsFilter"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie/memberAccountAssociation",
  "fqn": "pulumi_aws.macie",
  "classes": {
   "aws:macie/memberAccountAssociation:MemberAccountAssociation": "MemberAccountAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie/s3BucketAssociation",
  "fqn": "pulumi_aws.macie",
  "classes": {
   "aws:macie/s3BucketAssociation:S3BucketAssociation": "S3BucketAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie2/account",
  "fqn": "pulumi_aws.macie2",
  "classes": {
   "aws:macie2/account:Account": "Account"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie2/classificationJob",
  "fqn": "pulumi_aws.macie2",
  "classes": {
   "aws:macie2/classificationJob:ClassificationJob": "ClassificationJob"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie2/invitationAccepter",
  "fqn": "pulumi_aws.macie2",
  "classes": {
   "aws:macie2/invitationAccepter:InvitationAccepter": "InvitationAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie2/member",
  "fqn": "pulumi_aws.macie2",
  "classes": {
   "aws:macie2/member:Member": "Member"
  }
 },
 {
  "pkg": "aws",
  "mod": "macie2/organizationAdminAccount",
  "fqn": "pulumi_aws.macie2",
  "classes": {
   "aws:macie2/organizationAdminAccount:OrganizationAdminAccount": "OrganizationAdminAccount"
  }
 },
 {
  "pkg": "aws",
  "mod": "mediaconvert/queue",
  "fqn": "pulumi_aws.mediaconvert",
  "classes": {
   "aws:mediaconvert/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "aws",
  "mod": "mediapackage/channel",
  "fqn": "pulumi_aws.mediapackage",
  "classes": {
   "aws:mediapackage/channel:Channel": "Channel"
  }
 },
 {
  "pkg": "aws",
  "mod": "mediastore/container",
  "fqn": "pulumi_aws.mediastore",
  "classes": {
   "aws:mediastore/container:Container": "Container"
  }
 },
 {
  "pkg": "aws",
  "mod": "mediastore/containerPolicy",
  "fqn": "pulumi_aws.mediastore",
  "classes": {
   "aws:mediastore/containerPolicy:ContainerPolicy": "ContainerPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/acl",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/cluster",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/parameterGroup",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/snapshot",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/subnetGroup",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "memorydb/user",
  "fqn": "pulumi_aws.memorydb",
  "classes": {
   "aws:memorydb/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "mq/broker",
  "fqn": "pulumi_aws.mq",
  "classes": {
   "aws:mq/broker:Broker": "Broker"
  }
 },
 {
  "pkg": "aws",
  "mod": "mq/configuration",
  "fqn": "pulumi_aws.mq",
  "classes": {
   "aws:mq/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "aws",
  "mod": "msk/cluster",
  "fqn": "pulumi_aws.msk",
  "classes": {
   "aws:msk/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "msk/configuration",
  "fqn": "pulumi_aws.msk",
  "classes": {
   "aws:msk/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "aws",
  "mod": "msk/scramSecretAssociation",
  "fqn": "pulumi_aws.msk",
  "classes": {
   "aws:msk/scramSecretAssociation:ScramSecretAssociation": "ScramSecretAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "mskconnect/customPlugin",
  "fqn": "pulumi_aws.mskconnect",
  "classes": {
   "aws:mskconnect/customPlugin:CustomPlugin": "CustomPlugin"
  }
 },
 {
  "pkg": "aws",
  "mod": "mskconnect/workerConfiguration",
  "fqn": "pulumi_aws.mskconnect",
  "classes": {
   "aws:mskconnect/workerConfiguration:WorkerConfiguration": "WorkerConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "mwaa/environment",
  "fqn": "pulumi_aws.mwaa",
  "classes": {
   "aws:mwaa/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/cluster",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/clusterEndpoint",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/clusterEndpoint:ClusterEndpoint": "ClusterEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/clusterInstance",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/clusterInstance:ClusterInstance": "ClusterInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/clusterParameterGroup",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/clusterParameterGroup:ClusterParameterGroup": "ClusterParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/clusterSnapshot",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/clusterSnapshot:ClusterSnapshot": "ClusterSnapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/eventSubscription",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/parameterGroup",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "neptune/subnetGroup",
  "fqn": "pulumi_aws.neptune",
  "classes": {
   "aws:neptune/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkfirewall/firewall",
  "fqn": "pulumi_aws.networkfirewall",
  "classes": {
   "aws:networkfirewall/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkfirewall/firewallPolicy",
  "fqn": "pulumi_aws.networkfirewall",
  "classes": {
   "aws:networkfirewall/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkfirewall/loggingConfiguration",
  "fqn": "pulumi_aws.networkfirewall",
  "classes": {
   "aws:networkfirewall/loggingConfiguration:LoggingConfiguration": "LoggingConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkfirewall/resourcePolicy",
  "fqn": "pulumi_aws.networkfirewall",
  "classes": {
   "aws:networkfirewall/resourcePolicy:ResourcePolicy": "ResourcePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkfirewall/ruleGroup",
  "fqn": "pulumi_aws.networkfirewall",
  "classes": {
   "aws:networkfirewall/ruleGroup:RuleGroup": "RuleGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/connection",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/customerGatewayAssociation",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/customerGatewayAssociation:CustomerGatewayAssociation": "CustomerGatewayAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/device",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/device:Device": "Device"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/globalNetwork",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/globalNetwork:GlobalNetwork": "GlobalNetwork"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/link",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/link:Link": "Link"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/linkAssociation",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/linkAssociation:LinkAssociation": "LinkAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/site",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/site:Site": "Site"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/transitGatewayConnectPeerAssociation",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/transitGatewayConnectPeerAssociation:TransitGatewayConnectPeerAssociation": "TransitGatewayConnectPeerAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "networkmanager/transitGatewayRegistration",
  "fqn": "pulumi_aws.networkmanager",
  "classes": {
   "aws:networkmanager/transitGatewayRegistration:TransitGatewayRegistration": "TransitGatewayRegistration"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/application",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/application:Application": "Application"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/customLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/customLayer:CustomLayer": "CustomLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/ecsClusterLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/ecsClusterLayer:EcsClusterLayer": "EcsClusterLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/gangliaLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/gangliaLayer:GangliaLayer": "GangliaLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/haproxyLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/haproxyLayer:HaproxyLayer": "HaproxyLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/instance",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/javaAppLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/javaAppLayer:JavaAppLayer": "JavaAppLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/memcachedLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/memcachedLayer:MemcachedLayer": "MemcachedLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/mysqlLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/mysqlLayer:MysqlLayer": "MysqlLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/nodejsAppLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/nodejsAppLayer:NodejsAppLayer": "NodejsAppLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/permission",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/permission:Permission": "Permission"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/phpAppLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/phpAppLayer:PhpAppLayer": "PhpAppLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/railsAppLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/railsAppLayer:RailsAppLayer": "RailsAppLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/rdsDbInstance",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/rdsDbInstance:RdsDbInstance": "RdsDbInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/stack",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/stack:Stack": "Stack"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/staticWebLayer",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/staticWebLayer:StaticWebLayer": "StaticWebLayer"
  }
 },
 {
  "pkg": "aws",
  "mod": "opsworks/userProfile",
  "fqn": "pulumi_aws.opsworks",
  "classes": {
   "aws:opsworks/userProfile:UserProfile": "UserProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/account",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/account:Account": "Account"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/delegatedAdministrator",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/delegatedAdministrator:DelegatedAdministrator": "DelegatedAdministrator"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/organization",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/organizationalUnit",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/organizationalUnit:OrganizationalUnit": "OrganizationalUnit"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/policy",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "aws",
  "mod": "organizations/policyAttachment",
  "fqn": "pulumi_aws.organizations",
  "classes": {
   "aws:organizations/policyAttachment:PolicyAttachment": "PolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/admChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/admChannel:AdmChannel": "AdmChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/apnsChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/apnsChannel:ApnsChannel": "ApnsChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/apnsSandboxChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/apnsSandboxChannel:ApnsSandboxChannel": "ApnsSandboxChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/apnsVoipChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/apnsVoipChannel:ApnsVoipChannel": "ApnsVoipChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/apnsVoipSandboxChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/apnsVoipSandboxChannel:ApnsVoipSandboxChannel": "ApnsVoipSandboxChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/app",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/app:App": "App"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/baiduChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/baiduChannel:BaiduChannel": "BaiduChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/emailChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/emailChannel:EmailChannel": "EmailChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/eventStream",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/eventStream:EventStream": "EventStream"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/gcmChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/gcmChannel:GcmChannel": "GcmChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "pinpoint/smsChannel",
  "fqn": "pulumi_aws.pinpoint",
  "classes": {
   "aws:pinpoint/smsChannel:SmsChannel": "SmsChannel"
  }
 },
 {
  "pkg": "aws",
  "mod": "qldb/ledger",
  "fqn": "pulumi_aws.qldb",
  "classes": {
   "aws:qldb/ledger:Ledger": "Ledger"
  }
 },
 {
  "pkg": "aws",
  "mod": "quicksight/dataSource",
  "fqn": "pulumi_aws.quicksight",
  "classes": {
   "aws:quicksight/dataSource:DataSource": "DataSource"
  }
 },
 {
  "pkg": "aws",
  "mod": "quicksight/group",
  "fqn": "pulumi_aws.quicksight",
  "classes": {
   "aws:quicksight/group:Group": "Group"
  }
 },
 {
  "pkg": "aws",
  "mod": "quicksight/groupMembership",
  "fqn": "pulumi_aws.quicksight",
  "classes": {
   "aws:quicksight/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "aws",
  "mod": "quicksight/user",
  "fqn": "pulumi_aws.quicksight",
  "classes": {
   "aws:quicksight/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "ram/principalAssociation",
  "fqn": "pulumi_aws.ram",
  "classes": {
   "aws:ram/principalAssociation:PrincipalAssociation": "PrincipalAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ram/resourceAssociation",
  "fqn": "pulumi_aws.ram",
  "classes": {
   "aws:ram/resourceAssociation:ResourceAssociation": "ResourceAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ram/resourceShare",
  "fqn": "pulumi_aws.ram",
  "classes": {
   "aws:ram/resourceShare:ResourceShare": "ResourceShare"
  }
 },
 {
  "pkg": "aws",
  "mod": "ram/resourceShareAccepter",
  "fqn": "pulumi_aws.ram",
  "classes": {
   "aws:ram/resourceShareAccepter:ResourceShareAccepter": "ResourceShareAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/cluster",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/clusterEndpoint",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/clusterEndpoint:ClusterEndpoint": "ClusterEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/clusterInstance",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/clusterInstance:ClusterInstance": "ClusterInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/clusterParameterGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/clusterParameterGroup:ClusterParameterGroup": "ClusterParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/clusterRoleAssociation",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/clusterRoleAssociation:ClusterRoleAssociation": "ClusterRoleAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/clusterSnapshot",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/clusterSnapshot:ClusterSnapshot": "ClusterSnapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/eventSubscription",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/globalCluster",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/globalCluster:GlobalCluster": "GlobalCluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/instance",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/optionGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/optionGroup:OptionGroup": "OptionGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/parameterGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/proxy",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/proxy:Proxy": "Proxy"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/proxyDefaultTargetGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/proxyDefaultTargetGroup:ProxyDefaultTargetGroup": "ProxyDefaultTargetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/proxyEndpoint",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/proxyEndpoint:ProxyEndpoint": "ProxyEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/proxyTarget",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/proxyTarget:ProxyTarget": "ProxyTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/roleAssociation",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/roleAssociation:RoleAssociation": "RoleAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/securityGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/snapshot",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "aws",
  "mod": "rds/subnetGroup",
  "fqn": "pulumi_aws.rds",
  "classes": {
   "aws:rds/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/cluster",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/eventSubscription",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/parameterGroup",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/scheduledAction",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/scheduledAction:ScheduledAction": "ScheduledAction"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/securityGroup",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/snapshotCopyGrant",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/snapshotCopyGrant:SnapshotCopyGrant": "SnapshotCopyGrant"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/snapshotSchedule",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/snapshotSchedule:SnapshotSchedule": "SnapshotSchedule"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/snapshotScheduleAssociation",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/snapshotScheduleAssociation:SnapshotScheduleAssociation": "SnapshotScheduleAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "redshift/subnetGroup",
  "fqn": "pulumi_aws.redshift",
  "classes": {
   "aws:redshift/subnetGroup:SubnetGroup": "SubnetGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "resourcegroups/group",
  "fqn": "pulumi_aws.resourcegroups",
  "classes": {
   "aws:resourcegroups/group:Group": "Group"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/delegationSet",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/delegationSet:DelegationSet": "DelegationSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/healthCheck",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/healthCheck:HealthCheck": "HealthCheck"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/hostedZoneDnsSec",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/hostedZoneDnsSec:HostedZoneDnsSec": "HostedZoneDnsSec"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/keySigningKey",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/keySigningKey:KeySigningKey": "KeySigningKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/queryLog",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/queryLog:QueryLog": "QueryLog"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/record",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/record:Record": "Record"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverDnsSecConfig",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverDnsSecConfig:ResolverDnsSecConfig": "ResolverDnsSecConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverEndpoint",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverEndpoint:ResolverEndpoint": "ResolverEndpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverFirewallConfig",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverFirewallConfig:ResolverFirewallConfig": "ResolverFirewallConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverFirewallDomainList",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverFirewallDomainList:ResolverFirewallDomainList": "ResolverFirewallDomainList"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverFirewallRule",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverFirewallRule:ResolverFirewallRule": "ResolverFirewallRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverFirewallRuleGroup",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverFirewallRuleGroup:ResolverFirewallRuleGroup": "ResolverFirewallRuleGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverFirewallRuleGroupAssociation",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverFirewallRuleGroupAssociation:ResolverFirewallRuleGroupAssociation": "ResolverFirewallRuleGroupAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverQueryLogConfig",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverQueryLogConfig:ResolverQueryLogConfig": "ResolverQueryLogConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverQueryLogConfigAssociation",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverQueryLogConfigAssociation:ResolverQueryLogConfigAssociation": "ResolverQueryLogConfigAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverRule",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverRule:ResolverRule": "ResolverRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/resolverRuleAssociation",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/resolverRuleAssociation:ResolverRuleAssociation": "ResolverRuleAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/vpcAssociationAuthorization",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/vpcAssociationAuthorization:VpcAssociationAuthorization": "VpcAssociationAuthorization"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/zone",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53/zoneAssociation",
  "fqn": "pulumi_aws.route53",
  "classes": {
   "aws:route53/zoneAssociation:ZoneAssociation": "ZoneAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53domains/registeredDomain",
  "fqn": "pulumi_aws.route53domains",
  "classes": {
   "aws:route53domains/registeredDomain:RegisteredDomain": "RegisteredDomain"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoverycontrol/cluster",
  "fqn": "pulumi_aws.route53recoverycontrol",
  "classes": {
   "aws:route53recoverycontrol/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoverycontrol/controlPanel",
  "fqn": "pulumi_aws.route53recoverycontrol",
  "classes": {
   "aws:route53recoverycontrol/controlPanel:ControlPanel": "ControlPanel"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoverycontrol/routingControl",
  "fqn": "pulumi_aws.route53recoverycontrol",
  "classes": {
   "aws:route53recoverycontrol/routingControl:RoutingControl": "RoutingControl"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoverycontrol/safetyRule",
  "fqn": "pulumi_aws.route53recoverycontrol",
  "classes": {
   "aws:route53recoverycontrol/safetyRule:SafetyRule": "SafetyRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoveryreadiness/cell",
  "fqn": "pulumi_aws.route53recoveryreadiness",
  "classes": {
   "aws:route53recoveryreadiness/cell:Cell": "Cell"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoveryreadiness/readinessCheck",
  "fqn": "pulumi_aws.route53recoveryreadiness",
  "classes": {
   "aws:route53recoveryreadiness/readinessCheck:ReadinessCheck": "ReadinessCheck"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoveryreadiness/recoveryGroup",
  "fqn": "pulumi_aws.route53recoveryreadiness",
  "classes": {
   "aws:route53recoveryreadiness/recoveryGroup:RecoveryGroup": "RecoveryGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "route53recoveryreadiness/resourceSet",
  "fqn": "pulumi_aws.route53recoveryreadiness",
  "classes": {
   "aws:route53recoveryreadiness/resourceSet:ResourceSet": "ResourceSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/accessPoint",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/accessPoint:AccessPoint": "AccessPoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/accountPublicAccessBlock",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/accountPublicAccessBlock:AccountPublicAccessBlock": "AccountPublicAccessBlock"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/analyticsConfiguration",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/analyticsConfiguration:AnalyticsConfiguration": "AnalyticsConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucket",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketAccelerateConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketAccelerateConfigurationV2:BucketAccelerateConfigurationV2": "BucketAccelerateConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketAclV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketAclV2:BucketAclV2": "BucketAclV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketCorsConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketCorsConfigurationV2:BucketCorsConfigurationV2": "BucketCorsConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketIntelligentTieringConfiguration",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketIntelligentTieringConfiguration:BucketIntelligentTieringConfiguration": "BucketIntelligentTieringConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketLifecycleConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketLifecycleConfigurationV2:BucketLifecycleConfigurationV2": "BucketLifecycleConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketLoggingV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketLoggingV2:BucketLoggingV2": "BucketLoggingV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketMetric",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketMetric:BucketMetric": "BucketMetric"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketNotification",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketNotification:BucketNotification": "BucketNotification"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketObject",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketObject:BucketObject": "BucketObject"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketObjectLockConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketObjectLockConfigurationV2:BucketObjectLockConfigurationV2": "BucketObjectLockConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketObjectv2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketObjectv2:BucketObjectv2": "BucketObjectv2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketOwnershipControls",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketOwnershipControls:BucketOwnershipControls": "BucketOwnershipControls"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketPolicy",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketPolicy:BucketPolicy": "BucketPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketPublicAccessBlock",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketPublicAccessBlock:BucketPublicAccessBlock": "BucketPublicAccessBlock"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketReplicationConfig",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketReplicationConfig:BucketReplicationConfig": "BucketReplicationConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketRequestPaymentConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketRequestPaymentConfigurationV2:BucketRequestPaymentConfigurationV2": "BucketRequestPaymentConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketServerSideEncryptionConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketServerSideEncryptionConfigurationV2:BucketServerSideEncryptionConfigurationV2": "BucketServerSideEncryptionConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketV2:BucketV2": "BucketV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketVersioningV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketVersioningV2:BucketVersioningV2": "BucketVersioningV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/bucketWebsiteConfigurationV2",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/bucketWebsiteConfigurationV2:BucketWebsiteConfigurationV2": "BucketWebsiteConfigurationV2"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/inventory",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/inventory:Inventory": "Inventory"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3/objectCopy",
  "fqn": "pulumi_aws.s3",
  "classes": {
   "aws:s3/objectCopy:ObjectCopy": "ObjectCopy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/accessPointPolicy",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/accessPointPolicy:AccessPointPolicy": "AccessPointPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/bucket",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/bucketLifecycleConfiguration",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/bucketLifecycleConfiguration:BucketLifecycleConfiguration": "BucketLifecycleConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/bucketPolicy",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/bucketPolicy:BucketPolicy": "BucketPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/multiRegionAccessPoint",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/multiRegionAccessPoint:MultiRegionAccessPoint": "MultiRegionAccessPoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/multiRegionAccessPointPolicy",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/multiRegionAccessPointPolicy:MultiRegionAccessPointPolicy": "MultiRegionAccessPointPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/objectLambdaAccessPoint",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/objectLambdaAccessPoint:ObjectLambdaAccessPoint": "ObjectLambdaAccessPoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3control/objectLambdaAccessPointPolicy",
  "fqn": "pulumi_aws.s3control",
  "classes": {
   "aws:s3control/objectLambdaAccessPointPolicy:ObjectLambdaAccessPointPolicy": "ObjectLambdaAccessPointPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "s3outposts/endpoint",
  "fqn": "pulumi_aws.s3outposts",
  "classes": {
   "aws:s3outposts/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/app",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/app:App": "App"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/appImageConfig",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/appImageConfig:AppImageConfig": "AppImageConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/codeRepository",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/codeRepository:CodeRepository": "CodeRepository"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/device",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/device:Device": "Device"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/deviceFleet",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/deviceFleet:DeviceFleet": "DeviceFleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/domain",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/endpoint",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/endpointConfiguration",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/endpointConfiguration:EndpointConfiguration": "EndpointConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/featureGroup",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/featureGroup:FeatureGroup": "FeatureGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/flowDefinition",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/flowDefinition:FlowDefinition": "FlowDefinition"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/humanTaskUI",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/humanTaskUI:HumanTaskUI": "HumanTaskUI"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/image",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/image:Image": "Image"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/imageVersion",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/imageVersion:ImageVersion": "ImageVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/model",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/model:Model": "Model"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/modelPackageGroup",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/modelPackageGroup:ModelPackageGroup": "ModelPackageGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/modelPackageGroupPolicy",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/modelPackageGroupPolicy:ModelPackageGroupPolicy": "ModelPackageGroupPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/notebookInstance",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/notebookInstance:NotebookInstance": "NotebookInstance"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/notebookInstanceLifecycleConfiguration",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/notebookInstanceLifecycleConfiguration:NotebookInstanceLifecycleConfiguration": "NotebookInstanceLifecycleConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/project",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/project:Project": "Project"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/studioLifecycleConfig",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/studioLifecycleConfig:StudioLifecycleConfig": "StudioLifecycleConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/userProfile",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/userProfile:UserProfile": "UserProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/workforce",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/workforce:Workforce": "Workforce"
  }
 },
 {
  "pkg": "aws",
  "mod": "sagemaker/workteam",
  "fqn": "pulumi_aws.sagemaker",
  "classes": {
   "aws:sagemaker/workteam:Workteam": "Workteam"
  }
 },
 {
  "pkg": "aws",
  "mod": "schemas/discoverer",
  "fqn": "pulumi_aws.schemas",
  "classes": {
   "aws:schemas/discoverer:Discoverer": "Discoverer"
  }
 },
 {
  "pkg": "aws",
  "mod": "schemas/registry",
  "fqn": "pulumi_aws.schemas",
  "classes": {
   "aws:schemas/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "aws",
  "mod": "schemas/schema",
  "fqn": "pulumi_aws.schemas",
  "classes": {
   "aws:schemas/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "aws",
  "mod": "secretsmanager/secret",
  "fqn": "pulumi_aws.secretsmanager",
  "classes": {
   "aws:secretsmanager/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "aws",
  "mod": "secretsmanager/secretPolicy",
  "fqn": "pulumi_aws.secretsmanager",
  "classes": {
   "aws:secretsmanager/secretPolicy:SecretPolicy": "SecretPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "secretsmanager/secretRotation",
  "fqn": "pulumi_aws.secretsmanager",
  "classes": {
   "aws:secretsmanager/secretRotation:SecretRotation": "SecretRotation"
  }
 },
 {
  "pkg": "aws",
  "mod": "secretsmanager/secretVersion",
  "fqn": "pulumi_aws.secretsmanager",
  "classes": {
   "aws:secretsmanager/secretVersion:SecretVersion": "SecretVersion"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/account",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/account:Account": "Account"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/actionTarget",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/actionTarget:ActionTarget": "ActionTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/findingAggregator",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/findingAggregator:FindingAggregator": "FindingAggregator"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/insight",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/insight:Insight": "Insight"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/inviteAccepter",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/inviteAccepter:InviteAccepter": "InviteAccepter"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/member",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/member:Member": "Member"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/organizationAdminAccount",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/organizationAdminAccount:OrganizationAdminAccount": "OrganizationAdminAccount"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/organizationConfiguration",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/organizationConfiguration:OrganizationConfiguration": "OrganizationConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/productSubscription",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/productSubscription:ProductSubscription": "ProductSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/standardsControl",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/standardsControl:StandardsControl": "StandardsControl"
  }
 },
 {
  "pkg": "aws",
  "mod": "securityhub/standardsSubscription",
  "fqn": "pulumi_aws.securityhub",
  "classes": {
   "aws:securityhub/standardsSubscription:StandardsSubscription": "StandardsSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "serverlessrepository/cloudFormationStack",
  "fqn": "pulumi_aws.serverlessrepository",
  "classes": {
   "aws:serverlessrepository/cloudFormationStack:CloudFormationStack": "CloudFormationStack"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/budgetResourceAssociation",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/budgetResourceAssociation:BudgetResourceAssociation": "BudgetResourceAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/constraint",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/constraint:Constraint": "Constraint"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/organizationsAccess",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/organizationsAccess:OrganizationsAccess": "OrganizationsAccess"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/portfolio",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/portfolio:Portfolio": "Portfolio"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/portfolioShare",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/portfolioShare:PortfolioShare": "PortfolioShare"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/principalPortfolioAssociation",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/principalPortfolioAssociation:PrincipalPortfolioAssociation": "PrincipalPortfolioAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/product",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/product:Product": "Product"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/productPortfolioAssociation",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/productPortfolioAssociation:ProductPortfolioAssociation": "ProductPortfolioAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/provisionedProduct",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/provisionedProduct:ProvisionedProduct": "ProvisionedProduct"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/provisioningArtifact",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/provisioningArtifact:ProvisioningArtifact": "ProvisioningArtifact"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/serviceAction",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/serviceAction:ServiceAction": "ServiceAction"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/tagOption",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/tagOption:TagOption": "TagOption"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicecatalog/tagOptionResourceAssociation",
  "fqn": "pulumi_aws.servicecatalog",
  "classes": {
   "aws:servicecatalog/tagOptionResourceAssociation:TagOptionResourceAssociation": "TagOptionResourceAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicediscovery/httpNamespace",
  "fqn": "pulumi_aws.servicediscovery",
  "classes": {
   "aws:servicediscovery/httpNamespace:HttpNamespace": "HttpNamespace"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicediscovery/instance",
  "fqn": "pulumi_aws.servicediscovery",
  "classes": {
   "aws:servicediscovery/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicediscovery/privateDnsNamespace",
  "fqn": "pulumi_aws.servicediscovery",
  "classes": {
   "aws:servicediscovery/privateDnsNamespace:PrivateDnsNamespace": "PrivateDnsNamespace"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicediscovery/publicDnsNamespace",
  "fqn": "pulumi_aws.servicediscovery",
  "classes": {
   "aws:servicediscovery/publicDnsNamespace:PublicDnsNamespace": "PublicDnsNamespace"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicediscovery/service",
  "fqn": "pulumi_aws.servicediscovery",
  "classes": {
   "aws:servicediscovery/service:Service": "Service"
  }
 },
 {
  "pkg": "aws",
  "mod": "servicequotas/serviceQuota",
  "fqn": "pulumi_aws.servicequotas",
  "classes": {
   "aws:servicequotas/serviceQuota:ServiceQuota": "ServiceQuota"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/activeReceiptRuleSet",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/activeReceiptRuleSet:ActiveReceiptRuleSet": "ActiveReceiptRuleSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/confgurationSet",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/confgurationSet:ConfgurationSet": "ConfgurationSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/configurationSet",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/configurationSet:ConfigurationSet": "ConfigurationSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/domainDkim",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/domainDkim:DomainDkim": "DomainDkim"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/domainIdentity",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/domainIdentity:DomainIdentity": "DomainIdentity"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/domainIdentityVerification",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/domainIdentityVerification:DomainIdentityVerification": "DomainIdentityVerification"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/emailIdentity",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/emailIdentity:EmailIdentity": "EmailIdentity"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/eventDestination",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/eventDestination:EventDestination": "EventDestination"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/identityNotificationTopic",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/identityNotificationTopic:IdentityNotificationTopic": "IdentityNotificationTopic"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/identityPolicy",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/identityPolicy:IdentityPolicy": "IdentityPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/mailFrom",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/mailFrom:MailFrom": "MailFrom"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/receiptFilter",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/receiptFilter:ReceiptFilter": "ReceiptFilter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/receiptRule",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/receiptRule:ReceiptRule": "ReceiptRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/receiptRuleSet",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/receiptRuleSet:ReceiptRuleSet": "ReceiptRuleSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ses/template",
  "fqn": "pulumi_aws.ses",
  "classes": {
   "aws:ses/template:Template": "Template"
  }
 },
 {
  "pkg": "aws",
  "mod": "sfn/activity",
  "fqn": "pulumi_aws.sfn",
  "classes": {
   "aws:sfn/activity:Activity": "Activity"
  }
 },
 {
  "pkg": "aws",
  "mod": "sfn/stateMachine",
  "fqn": "pulumi_aws.sfn",
  "classes": {
   "aws:sfn/stateMachine:StateMachine": "StateMachine"
  }
 },
 {
  "pkg": "aws",
  "mod": "shield/protection",
  "fqn": "pulumi_aws.shield",
  "classes": {
   "aws:shield/protection:Protection": "Protection"
  }
 },
 {
  "pkg": "aws",
  "mod": "shield/protectionGroup",
  "fqn": "pulumi_aws.shield",
  "classes": {
   "aws:shield/protectionGroup:ProtectionGroup": "ProtectionGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "shield/protectionHealthCheckAssociation",
  "fqn": "pulumi_aws.shield",
  "classes": {
   "aws:shield/protectionHealthCheckAssociation:ProtectionHealthCheckAssociation": "ProtectionHealthCheckAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "signer/signingJob",
  "fqn": "pulumi_aws.signer",
  "classes": {
   "aws:signer/signingJob:SigningJob": "SigningJob"
  }
 },
 {
  "pkg": "aws",
  "mod": "signer/signingProfile",
  "fqn": "pulumi_aws.signer",
  "classes": {
   "aws:signer/signingProfile:SigningProfile": "SigningProfile"
  }
 },
 {
  "pkg": "aws",
  "mod": "signer/signingProfilePermission",
  "fqn": "pulumi_aws.signer",
  "classes": {
   "aws:signer/signingProfilePermission:SigningProfilePermission": "SigningProfilePermission"
  }
 },
 {
  "pkg": "aws",
  "mod": "simpledb/domain",
  "fqn": "pulumi_aws.simpledb",
  "classes": {
   "aws:simpledb/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "sns/platformApplication",
  "fqn": "pulumi_aws.sns",
  "classes": {
   "aws:sns/platformApplication:PlatformApplication": "PlatformApplication"
  }
 },
 {
  "pkg": "aws",
  "mod": "sns/smsPreferences",
  "fqn": "pulumi_aws.sns",
  "classes": {
   "aws:sns/smsPreferences:SmsPreferences": "SmsPreferences"
  }
 },
 {
  "pkg": "aws",
  "mod": "sns/topic",
  "fqn": "pulumi_aws.sns",
  "classes": {
   "aws:sns/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "aws",
  "mod": "sns/topicPolicy",
  "fqn": "pulumi_aws.sns",
  "classes": {
   "aws:sns/topicPolicy:TopicPolicy": "TopicPolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "sns/topicSubscription",
  "fqn": "pulumi_aws.sns",
  "classes": {
   "aws:sns/topicSubscription:TopicSubscription": "TopicSubscription"
  }
 },
 {
  "pkg": "aws",
  "mod": "sqs/queue",
  "fqn": "pulumi_aws.sqs",
  "classes": {
   "aws:sqs/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "aws",
  "mod": "sqs/queuePolicy",
  "fqn": "pulumi_aws.sqs",
  "classes": {
   "aws:sqs/queuePolicy:QueuePolicy": "QueuePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/activation",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/activation:Activation": "Activation"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/association",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/association:Association": "Association"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/document",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/document:Document": "Document"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/maintenanceWindow",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/maintenanceWindow:MaintenanceWindow": "MaintenanceWindow"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/maintenanceWindowTarget",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/maintenanceWindowTarget:MaintenanceWindowTarget": "MaintenanceWindowTarget"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/maintenanceWindowTask",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/maintenanceWindowTask:MaintenanceWindowTask": "MaintenanceWindowTask"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/parameter",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/parameter:Parameter": "Parameter"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/patchBaseline",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/patchBaseline:PatchBaseline": "PatchBaseline"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/patchGroup",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/patchGroup:PatchGroup": "PatchGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssm/resourceDataSync",
  "fqn": "pulumi_aws.ssm",
  "classes": {
   "aws:ssm/resourceDataSync:ResourceDataSync": "ResourceDataSync"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssoadmin/accountAssignment",
  "fqn": "pulumi_aws.ssoadmin",
  "classes": {
   "aws:ssoadmin/accountAssignment:AccountAssignment": "AccountAssignment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssoadmin/managedPolicyAttachment",
  "fqn": "pulumi_aws.ssoadmin",
  "classes": {
   "aws:ssoadmin/managedPolicyAttachment:ManagedPolicyAttachment": "ManagedPolicyAttachment"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssoadmin/permissionSet",
  "fqn": "pulumi_aws.ssoadmin",
  "classes": {
   "aws:ssoadmin/permissionSet:PermissionSet": "PermissionSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "ssoadmin/permissionSetInlinePolicy",
  "fqn": "pulumi_aws.ssoadmin",
  "classes": {
   "aws:ssoadmin/permissionSetInlinePolicy:PermissionSetInlinePolicy": "PermissionSetInlinePolicy"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/cache",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/cache:Cache": "Cache"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/cachesIscsiVolume",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/cachesIscsiVolume:CachesIscsiVolume": "CachesIscsiVolume"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/fileSystemAssociation",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/fileSystemAssociation:FileSystemAssociation": "FileSystemAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/gateway",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/nfsFileShare",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/nfsFileShare:NfsFileShare": "NfsFileShare"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/smbFileShare",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/smbFileShare:SmbFileShare": "SmbFileShare"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/storedIscsiVolume",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/storedIscsiVolume:StoredIscsiVolume": "StoredIscsiVolume"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/tapePool",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/tapePool:TapePool": "TapePool"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/uploadBuffer",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/uploadBuffer:UploadBuffer": "UploadBuffer"
  }
 },
 {
  "pkg": "aws",
  "mod": "storagegateway/workingStorage",
  "fqn": "pulumi_aws.storagegateway",
  "classes": {
   "aws:storagegateway/workingStorage:WorkingStorage": "WorkingStorage"
  }
 },
 {
  "pkg": "aws",
  "mod": "swf/domain",
  "fqn": "pulumi_aws.swf",
  "classes": {
   "aws:swf/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "aws",
  "mod": "synthetics/canary",
  "fqn": "pulumi_aws.synthetics",
  "classes": {
   "aws:synthetics/canary:Canary": "Canary"
  }
 },
 {
  "pkg": "aws",
  "mod": "timestreamwrite/database",
  "fqn": "pulumi_aws.timestreamwrite",
  "classes": {
   "aws:timestreamwrite/database:Database": "Database"
  }
 },
 {
  "pkg": "aws",
  "mod": "timestreamwrite/table",
  "fqn": "pulumi_aws.timestreamwrite",
  "classes": {
   "aws:timestreamwrite/table:Table": "Table"
  }
 },
 {
  "pkg": "aws",
  "mod": "transfer/access",
  "fqn": "pulumi_aws.transfer",
  "classes": {
   "aws:transfer/access:Access": "Access"
  }
 },
 {
  "pkg": "aws",
  "mod": "transfer/server",
  "fqn": "pulumi_aws.transfer",
  "classes": {
   "aws:transfer/server:Server": "Server"
  }
 },
 {
  "pkg": "aws",
  "mod": "transfer/sshKey",
  "fqn": "pulumi_aws.transfer",
  "classes": {
   "aws:transfer/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "aws",
  "mod": "transfer/user",
  "fqn": "pulumi_aws.transfer",
  "classes": {
   "aws:transfer/user:User": "User"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/byteMatchSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/byteMatchSet:ByteMatchSet": "ByteMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/geoMatchSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/geoMatchSet:GeoMatchSet": "GeoMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/ipSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/ipSet:IpSet": "IpSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/rateBasedRule",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/rateBasedRule:RateBasedRule": "RateBasedRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/regexMatchSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/regexMatchSet:RegexMatchSet": "RegexMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/regexPatternSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/regexPatternSet:RegexPatternSet": "RegexPatternSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/rule",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/ruleGroup",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/ruleGroup:RuleGroup": "RuleGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/sizeConstraintSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/sizeConstraintSet:SizeConstraintSet": "SizeConstraintSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/sqlInjectionMatchSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/sqlInjectionMatchSet:SqlInjectionMatchSet": "SqlInjectionMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/webAcl",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/webAcl:WebAcl": "WebAcl"
  }
 },
 {
  "pkg": "aws",
  "mod": "waf/xssMatchSet",
  "fqn": "pulumi_aws.waf",
  "classes": {
   "aws:waf/xssMatchSet:XssMatchSet": "XssMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/byteMatchSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/byteMatchSet:ByteMatchSet": "ByteMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/geoMatchSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/geoMatchSet:GeoMatchSet": "GeoMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/ipSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/ipSet:IpSet": "IpSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/rateBasedRule",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/rateBasedRule:RateBasedRule": "RateBasedRule"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/regexMatchSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/regexMatchSet:RegexMatchSet": "RegexMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/regexPatternSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/regexPatternSet:RegexPatternSet": "RegexPatternSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/rule",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/ruleGroup",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/ruleGroup:RuleGroup": "RuleGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/sizeConstraintSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/sizeConstraintSet:SizeConstraintSet": "SizeConstraintSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/sqlInjectionMatchSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/sqlInjectionMatchSet:SqlInjectionMatchSet": "SqlInjectionMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/webAcl",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/webAcl:WebAcl": "WebAcl"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/webAclAssociation",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/webAclAssociation:WebAclAssociation": "WebAclAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafregional/xssMatchSet",
  "fqn": "pulumi_aws.wafregional",
  "classes": {
   "aws:wafregional/xssMatchSet:XssMatchSet": "XssMatchSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/ipSet",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/ipSet:IpSet": "IpSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/regexPatternSet",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/regexPatternSet:RegexPatternSet": "RegexPatternSet"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/ruleGroup",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/ruleGroup:RuleGroup": "RuleGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/webAcl",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/webAcl:WebAcl": "WebAcl"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/webAclAssociation",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/webAclAssociation:WebAclAssociation": "WebAclAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "wafv2/webAclLoggingConfiguration",
  "fqn": "pulumi_aws.wafv2",
  "classes": {
   "aws:wafv2/webAclLoggingConfiguration:WebAclLoggingConfiguration": "WebAclLoggingConfiguration"
  }
 },
 {
  "pkg": "aws",
  "mod": "worklink/fleet",
  "fqn": "pulumi_aws.worklink",
  "classes": {
   "aws:worklink/fleet:Fleet": "Fleet"
  }
 },
 {
  "pkg": "aws",
  "mod": "worklink/websiteCertificateAuthorityAssociation",
  "fqn": "pulumi_aws.worklink",
  "classes": {
   "aws:worklink/websiteCertificateAuthorityAssociation:WebsiteCertificateAuthorityAssociation": "WebsiteCertificateAuthorityAssociation"
  }
 },
 {
  "pkg": "aws",
  "mod": "workspaces/directory",
  "fqn": "pulumi_aws.workspaces",
  "classes": {
   "aws:workspaces/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "aws",
  "mod": "workspaces/ipGroup",
  "fqn": "pulumi_aws.workspaces",
  "classes": {
   "aws:workspaces/ipGroup:IpGroup": "IpGroup"
  }
 },
 {
  "pkg": "aws",
  "mod": "workspaces/workspace",
  "fqn": "pulumi_aws.workspaces",
  "classes": {
   "aws:workspaces/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "aws",
  "mod": "xray/encryptionConfig",
  "fqn": "pulumi_aws.xray",
  "classes": {
   "aws:xray/encryptionConfig:EncryptionConfig": "EncryptionConfig"
  }
 },
 {
  "pkg": "aws",
  "mod": "xray/group",
  "fqn": "pulumi_aws.xray",
  "classes": {
   "aws:xray/group:Group": "Group"
  }
 },
 {
  "pkg": "aws",
  "mod": "xray/samplingRule",
  "fqn": "pulumi_aws.xray",
  "classes": {
   "aws:xray/samplingRule:SamplingRule": "SamplingRule"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "aws",
  "token": "pulumi:providers:aws",
  "fqn": "pulumi_aws",
  "class": "Provider"
 }
]
"""
)
